@@ -1,7 +1,7 @@
-
 sed \
 	-e 's/#_0028swbis_005f\(.[^_]*\)_0029/\1.html#/g' \
-	-e 's/_003a//g' \
+	-e 's/_003a//g' |
+sed \
 	-e 's/swpackage.html#"/swpackage_8.html"/' \
 	-e 's/swinstall.html#"/swinstall_8.html"/' \
 	-e 's/swcopy.html#"/swcopy_8.html"/' \
