@@ -91,6 +91,22 @@ void * malloc_fprintf(int sz, const char *format, ...);
 
 #define SWBISNEEDFAIL 1	/* Should be on even for production use. */
 
+/*
+ * Controlled outside this file
+ * #define FILENEEDDEBUG
+ * #undef FILENEEDDEBUG
+ */
+#ifdef FILENEEDDEBUG
+#define E_DEBUG(format) SWBISERROR("DEBUG: ", format)
+#define E_DEBUG2(format, arg) SWBISERROR2("DEBUG: ", format, arg)
+#define E_DEBUG3(format, arg, arg1) \
+			SWBISERROR3("DEBUG: ", format, arg, arg1)
+#else
+#define E_DEBUG(arg)
+#define E_DEBUG2(arg, arg1)
+#define E_DEBUG3(arg, arg1, arg2)
+#endif
+
 #ifdef SWBISNEEDFAIL
 #define SWBIS_E_FAIL(format) SWBISERROR("INTERNAL ERROR: ", format)
 #define SWBIS_E_FAIL2(format, arg) SWBISERROR2("INTERNAL ERROR: ", format, arg)
@@ -111,7 +127,6 @@ void * malloc_fprintf(int sz, const char *format, ...);
 #define SWBIS_E_DEBUG3(arg, arg1, arg2)
 #endif /* SWBISNEEDDEBUG */
 
-
 /*
 * =====================
 */
