@@ -17,6 +17,8 @@
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 
+#define FILENEEDDEBUG 1
+#undef FILENEEDDEBUG
 #include "swuser_config.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -40,6 +42,7 @@
 #include "swutillib.h"
 #include "atomicio.h"
 #include "swutilname.h"
+#include "globalblob.h"
 
 char * CHARTRUE = "true";
  
@@ -107,14 +110,18 @@ writeline(int do_stderr, int do_log, int logfd, int efd, char * sptr, int len)
 	int eret = 0;
 	int lret = 0;
 
+	E_DEBUG("");
+	E_DEBUG3("do_log=%d  logfd=%d", do_log, logfd);
+	E_DEBUG3("do_stderr=%d  efd=%d", do_stderr, efd);
 	if (do_stderr) {
 		eret = atomicio((ssize_t (*)(int, void *, size_t))write,
 					efd, sptr, len);
 	}
 	if (do_log && logfd > 0)
-		lret = swlib_writelogline(logfd, sptr);
+		lret = swutil_writelogline(logfd, sptr);
 	ret = eret;
 	ret = lret < 0 ? lret : ret;
+	E_DEBUG2("return = %d", ret);
 	return ret;
 }
 
@@ -123,6 +130,8 @@ int
 test_verbose(int verbose_level, int swbis_event,
 			int is_swi_event, int event_status, int is_posix_event)
 {
+	E_DEBUG3("verbose_level=%d  swbis_event=%d", verbose_level, swbis_event);
+	E_DEBUG3("is_swi_event=%d  event_status=%d", is_swi_event, event_status);
 	if (
 		(verbose_level >= SWC_VERBOSE_1 && 
 				event_status != 0) ||
@@ -131,8 +140,10 @@ test_verbose(int verbose_level, int swbis_event,
 		(verbose_level >= SWC_VERBOSE_6 && is_swi_event) ||
 		(verbose_level >= SWC_VERBOSE_4 && !is_swi_event)
 	) {
+		E_DEBUG("returning 1");
 		return 1;
 	} else {
+		E_DEBUG("returning 0");
 		return 0;
 	}
 }
@@ -169,7 +180,7 @@ is_event(char * line, int * status,
 
 static
 int
-write_error_line(struct sw_logspec * logspec, int vofd, int vefd, char * sptr, int len,
+write_error_line(GB * G, struct sw_logspec * logspec, int vofd, int vefd, char * sptr, int len,
 			int verbose_level, int swi_event_fd)
 {
 	int evret = 0;
@@ -182,13 +193,18 @@ write_error_line(struct sw_logspec * logspec, int vofd, int vefd, char * sptr, i
 	int do_log = 0;
 	int do_stderr = 0;
 
+	E_DEBUG("");
+	E_DEBUG2("verbose_level=%d" , verbose_level);
+	E_DEBUG3("vefd=%d  vofd=%d", vefd, vofd);
 	if (is_event(sptr, &event_status, &swbis_event, &is_swi_event, &is_posix_event)) {
+		E_DEBUG("");
 		if (swi_event_fd >= 0) {
 			/*
 			 * swi_event_fd is the pipe to the swi_<*> routine
 			 * which is gated by these events in an expect/send
 			 * type of arrangement.
 			 */
+			E_DEBUG("");
 			news = strdup(sptr);
 			/* fprintf(stderr, "JLX [%s]\n", news); */
 			evret = swevent_write_rpsh_event(swi_event_fd, news, len);
@@ -200,44 +216,45 @@ write_error_line(struct sw_logspec * logspec, int vofd, int vefd, char * sptr, i
 			free(news);
 		}
 
-		/*
-		do_log = test_verbose(logspec->loglevelM, swbis_event,
-					is_swi_event, event_status, is_posix_event);
-		*/
-
 		if (is_swi_event == 0) {
+			E_DEBUG("");
 			do_log = 1;
 		} else {
+			E_DEBUG("");
 			do_log = 0;
 		}
 
-		/*
-		do_log = swlib_do_log_is_true(logspec, verbose_level, write_at_level);
-		*/
-
 		do_stderr = swlib_test_verbose(verbose_level, swbis_event,
 					is_swi_event, event_status, is_posix_event);
 		if (
 			do_log || do_stderr
 		) {
+			E_DEBUG("");
 			if (event_status) {
 				/*
 				* the status indicates an error ocurred.
 				*/
+				E_DEBUG("calling writeline");
 				ret = writeline(do_stderr, do_log, logspec->logfdM, vefd, sptr, len);
 			} else {
-				if (vofd >= 0)
+				E_DEBUG("");
+				if (vofd >= 0) {
+					E_DEBUG("calling writeline");
 					ret = writeline(do_stderr, do_log,
 						logspec->logfdM, vofd, sptr, len);
+				}
 			}
 		} else {
+			E_DEBUG("nothing");
 			;
 		}
 	} else {
 		if (logspec->loglevelM > 0) {
+			E_DEBUG("");
 			 do_log = 1;
 		}
 		if (verbose_level > 0 ) {
+			E_DEBUG("");
 			if (
 				is_unix_sys_error(sptr) || 
 				verbose_level >= SWC_VERBOSE_6
@@ -245,22 +262,25 @@ write_error_line(struct sw_logspec * logspec, int vofd, int vefd, char * sptr, i
 				/*
 				* Error, send to stderr.
 				*/
+				E_DEBUG("calling writeline");
 				do_stderr = 1;
 				ret = writeline(do_stderr, do_log, logspec->logfdM, vefd, sptr, len);
 			} else {
 				/*
 				* Info, send to stdout.
 				*/
+				E_DEBUG("");
 				if (logspec->loglevelM >= 2) {
 					do_log = 1;
 				} else {
 					do_log = 0;
 				}
-				if (verbose_level >= SWC_VERBOSE_4) {
+				if (verbose_level >= G->g_verbose_threshold) {
 					do_stderr = 1;
 				} else {
 					do_stderr = 0;
 				}
+				E_DEBUG("calling writeline");
 				ret = writeline(do_stderr, do_log, logspec->logfdM, vofd, sptr, len);
 			}
 		} 
@@ -270,7 +290,7 @@ write_error_line(struct sw_logspec * logspec, int vofd, int vefd, char * sptr, i
 
 static
 int
-write_log(STROB * linebuf, struct sw_logspec * logspec, int vofd, int vefd, void * bufa,
+write_log(GB * G, STROB * linebuf, struct sw_logspec * logspec, int vofd, int vefd, void * bufa,
 			size_t len, int verbose_level, int swi_event_fd)
 {
 	char * s;
@@ -285,7 +305,7 @@ write_log(STROB * linebuf, struct sw_logspec * logspec, int vofd, int vefd, void
 	while(nl) {
 		s1 = *(nl+1);	
 		*(nl + 1) = '\0';
-		ret = write_error_line(logspec, vofd, vefd, s, strlen(s),
+		ret = write_error_line(G, logspec, vofd, vefd, s, strlen(s),
 					verbose_level, swi_event_fd);
 		if (ret < 0) return -1;
 		if (ret > 0) tot += ret;
@@ -937,7 +957,7 @@ swc_run_ssh_command (
 			_exit(1);
 		}
 
-		if (ts_pid <= 0) {
+		if (ts_pid < 0) {
 			fprintf(stderr, "fork error : %s\n", strerror(errno));
 			_exit(1);
 		}
@@ -1186,18 +1206,18 @@ swc_get_next_target(char ** argvector,
 }
 
 void
-swc_flush_logger(STROB * slinebuf, STROB * tlinebuf,
+swc_flush_logger(GB * G, STROB * slinebuf, STROB * tlinebuf,
 		int efd, int ofd, struct sw_logspec * logspec, int verboselevel)
 {
-	write_log(slinebuf, logspec, ofd, efd, "", 0, verboselevel, -1);
-	write_log(tlinebuf, logspec, ofd, efd, "", 0, verboselevel, -1);
+	write_log(G, slinebuf, logspec, ofd, efd, "", 0, verboselevel, -1);
+	write_log(G, tlinebuf, logspec, ofd, efd, "", 0, verboselevel, -1);
 	if (logspec && logspec->logfdM > 0) {
 		close(logspec->logfdM);
 	}
 }
 
 pid_t
-swc_fork_logger(STROB * x_slinebuf, STROB * x_tlinebuf, int efd, int ofd,
+swc_fork_logger(GB * G, STROB * x_slinebuf, STROB * x_tlinebuf, int efd, int ofd,
 		struct sw_logspec * logspec, int * s_efd, int * t_efd,
 		int vlevel, int * swi_event_fd_p)
 {
@@ -1210,14 +1230,10 @@ swc_fork_logger(STROB * x_slinebuf, STROB * x_tlinebuf, int efd, int ofd,
 	STROB * slinebuf = strob_open(100);
 	STROB * tlinebuf = strob_open(100);
 
-	/* fprintf(stderr, "logfdM=%d loglevel=%d\n", logspec->logfdM, logspec->loglevelM);
-	*/
-
 	if (pipe(spipe) < 0) return -1;
 	if (pipe(tpipe) < 0) return -1;
 	if (swi_event_fd_p) {
 		if (pipe(ppipe) < 0) return -1;
-		/* fprintf(stderr, "ppipe[0]=%d ppipe[1]=%d\n", ppipe[0], ppipe[1]); */
 	} else {
 		ppipe[0] = -1;
 		ppipe[1] = -1;
@@ -1252,14 +1268,14 @@ swc_fork_logger(STROB * x_slinebuf, STROB * x_tlinebuf, int efd, int ofd,
 		memset(bufb, '\0', SWLIB_PIPE_BUF + SWLIB_PIPE_BUF);
 
 		/*
-		* Force all file descriptors to 6 or below and
-		* close all descriptors greater than 6.
-		*/
+		 * Force all file descriptors to 6 or below and
+		 * close all descriptors greater than 6.
+		 */
 		if (spipe[0] <= 5 || tpipe[0] <= 5 ||
 			(ppipe[1] >= 0 && ppipe[1] <= 5) ) {
 			/*
-			* Sanity check.
-			*/
+			 * Sanity check.
+			 */
 			fprintf(stderr, "%s: internal error in fork_logger\n",
 				swlib_utilname_get());
 			return -1;
@@ -1303,7 +1319,7 @@ swc_fork_logger(STROB * x_slinebuf, STROB * x_tlinebuf, int efd, int ofd,
 			}
 			if (rra > 0) {
 				/* fprintf(stderr, "JL rra: %s\n", bufa); */
-				write_log(slinebuf, logspec, ofd, efd, bufa, rra, vlevel, ppipe[1]);
+				write_log(G, slinebuf, logspec, ofd, efd, bufa, rra, vlevel, ppipe[1]);
 			}
 			if (!doneb) {
 				srb = swgpReadFdNonblock(bufb, 4 /*tpipe[0]*/, &rrb);
@@ -1311,7 +1327,7 @@ swc_fork_logger(STROB * x_slinebuf, STROB * x_tlinebuf, int efd, int ofd,
 			}
 			if (rrb > 0) {
 				/* fprintf(stderr, "JL rrb: %s\n", bufb); */
-				write_log(tlinebuf, logspec, ofd, efd, bufb, rrb, vlevel, ppipe[1]);
+				write_log(G, tlinebuf, logspec, ofd, efd, bufb, rrb, vlevel, ppipe[1]);
 			}
 		}
 		status = 0;
@@ -1333,10 +1349,10 @@ swc_fork_logger(STROB * x_slinebuf, STROB * x_tlinebuf, int efd, int ofd,
 					break;
 			}
 			swlib_doif_writef(vlevel, status ? 1: SWC_VERBOSE_6, logspec, efd, "%s", strob_str(tmp));
-			swc_flush_logger(slinebuf, tlinebuf, efd, ofd, logspec, vlevel);
+			swc_flush_logger(G, slinebuf, tlinebuf, efd, ofd, logspec, vlevel);
 		} else {
 			swlib_doif_writef(vlevel, SWC_VERBOSE_8, logspec, efd, "logger unexpected exit.\n");
-			swc_flush_logger(slinebuf, tlinebuf, efd, ofd, logspec, vlevel);
+			swc_flush_logger(G, slinebuf, tlinebuf, efd, ofd, logspec, vlevel);
 		}
 		_exit(status);
 	}
@@ -1386,6 +1402,33 @@ swc_get_pax_read_command(struct g_pax_read_command g_pax_read_commands[],
 				verbose_level, keep, DEFAULT_PAX_R);
 }
 
+char *
+swc_get_pax_write_command(struct g_pax_write_command g_pax_write_commands[],
+			char * keyid, int verbose_level, char * paxdefault)
+{
+	int i = 0;
+	char * id;
+	struct g_pax_write_command * writecmd;
+
+	if (! keyid) return NULL;
+	
+	if (strlen(keyid) == 0) {
+		return swc_get_pax_write_command(g_pax_write_commands, DEFAULT_PAX_W, 
+						verbose_level, DEFAULT_PAX_W);
+	}
+	writecmd = &(g_pax_write_commands[i]);
+	id = writecmd->idM;
+	while (id) {
+		if (strcmp(keyid, id) == 0) return writecmd->commandM;
+		i++;
+		writecmd = &(g_pax_write_commands[i]);
+		id = writecmd->idM;
+	}
+
+	return swc_get_pax_write_command(g_pax_write_commands, paxdefault, 
+					verbose_level, DEFAULT_PAX_W);
+}
+
 int
 swc_process_swoperand_file(SWUTIL * swutil,
 		char * type_string,
@@ -1418,3 +1461,672 @@ swc_process_swoperand_file(SWUTIL * swutil,
 	fd_array[(*p_array_index)] = -1;
 	return 0;
 }
+
+void
+swc_set_boolean_x_option(struct extendedOptions * opta, 
+		enum eOpts nopt, 
+		char * arg, 
+		char ** optionp)
+{
+	if (strcasecmp(arg, "true") == 0) {
+		*optionp = "true";
+	} else {
+		*optionp = "false";
+	}
+	set_opta(opta, nopt, *optionp);
+}
+
+int
+swc_write_source_copy_script(GB * G,
+	int ofd, 
+	char * sourcepath, 
+	int do_get_file_type, 
+	int verbose_threshold,
+	int delaytime,
+	int nhops,
+	char * pax_write_command_key,
+	char * hostname,
+	char * blocksize
+	)
+{
+	int ret;
+	char * dirname, *path;
+	char * pax_write_command;
+	STROB * buffer, *opt1, *opt2;
+	STROB * subsh, *subsh2;
+	STROB * tmp;
+	STROB * tmp1;
+	STROB * tmp2;
+	STROB * set_vx;
+	STROB * to_devnull;
+	int vlv;
+
+	vlv = G->g_verboseG;
+	/*
+	 * error for source script is >0
+	 */
+	if (strstr(sourcepath, "..") == sourcepath) { return 1; }
+	if (strstr(sourcepath, "../")) { return 1; }
+	if (swlib_is_sh_tainted_string(sourcepath)) { return 1; }
+	/*
+	 * Squash the trailing slash.
+	 */
+	swlib_squash_double_slash(sourcepath);
+	if (strlen(sourcepath) > 1) {
+		if (sourcepath[strlen(sourcepath) - 1] == '/' ) {
+			sourcepath[strlen(sourcepath) - 1] = '\0';
+		}
+	}
+
+	buffer = strob_open(1);
+	to_devnull = strob_open(10);
+	opt1 = strob_open(1);
+	opt2 = strob_open(1);
+	set_vx = strob_open(10);
+	tmp = strob_open(10);
+	tmp1 = strob_open(10);
+	tmp2 = strob_open(10);
+	subsh = strob_open(10);
+	subsh2 = strob_open(10);
+
+	if (vlv >= SWC_VERBOSE_SWIDB) {
+		strob_strcpy(set_vx, "set -vx\n");
+	}
+	
+	if (vlv <= verbose_threshold ) {
+		strob_strcpy(to_devnull, "2>/dev/null");
+	}
+	
+	swlib_dirname(tmp, sourcepath);
+	dirname = strdup(strob_str(tmp));
+
+	swlib_basename(tmp, sourcepath);
+	path = strdup(strob_str(tmp));
+
+	if (do_get_file_type) {
+		if (strchr(path, '\n') || 
+			strlen(path) > MAX_CONTROL_MESG_LEN - 
+				strlen(SWBIS_SWINSTALL_SOURCE_CTL_ARCHIVE ":")
+		) {
+			/*
+			 * Too long, or path Contains a newline char.
+			 */
+			return 1;
+		}
+		/*
+		 * this is the control message.
+		 */
+		strob_sprintf(opt1, 0, 
+		"echo " "\"" SWBIS_SWINSTALL_SOURCE_CTL_ARCHIVE ": %s\"",
+			path
+			);
+		strob_sprintf(opt2, 0, 
+		"echo " "\""SWBIS_SWINSTALL_SOURCE_CTL_DIRECTORY ": %s\"",
+			 path
+			);
+	}
+	
+	pax_write_command = swc_get_pax_write_command(G->g_pax_write_commands, pax_write_command_key,
+						G->g_verboseG, DEFAULT_PAX_W);
+
+	if (swlib_is_sh_tainted_string(path)) { return 1; }
+	if (swlib_is_sh_tainted_string(dirname)) { return 1; }
+
+	if (
+		strcmp(path, "/") == 0 &&
+		strcmp(dirname, "/") == 0
+	) {
+		free(path);
+		path = strdup(".");	
+	}
+
+	strob_sprintf(tmp1, 0, "%s", path),
+	strob_sprintf(tmp2, 0, "%s", sourcepath),
+	ret = swlib_writef(ofd, buffer, 	
+		"echo " SWBIS_TARGET_CTL_MSG_125 ": " KILL_PID "\n"
+		"%s\n"
+		"%s"
+		"%s"
+		"blocksize=\"%s\"\n"
+		"dirname=\"%s\"\n"
+		"path=\"%s\"\n"
+		"sourcepath=\"%s\"\n"
+		"sw_retval=0\n"
+		"sb__delaytime=%d\n"
+
+		"if test -d \"$dirname\"; then\n"
+		"	cd \"$dirname\"\n"
+		"	sw_retval=$?\n"
+		"	case $sw_retval in\n"
+		"	0)\n"
+		"	if test -d \"$path\" -a -r \"$path\"; then\n"
+				"\t\t%s\n"
+				"\t\t%s\n"
+				"\t\t%s\n"
+		"		%s \"$path\"\n"
+		"		sw_retval=$?\n"
+				"\t\t%s\n"
+		"	elif test -e \"$path\" -a -r \"$path\"; then\n"
+				"\t\t%s\n"
+				"\t\t%s\n"
+				"\t\t%s\n"
+		"		dd ibs=\"$blocksize\" obs=512 if=\"$path\" %s;\n"
+		"		sw_retval=$?\n"
+				"\t\t%s\n"
+		"	else\n"
+				"\t\t%s\n"
+				"\t\t%s\n"
+		"		sw_retval=1\n"
+		"	fi\n"
+		"	;;\n"
+		"	*)\n"
+			"\t\t%s\n"
+			"\t\t%s\n"
+		"	;;\n"
+		"	esac\n"
+
+		"elif test -e \"$sourcepath\" -a -r \"$sourcepath\"; then\n"
+			"\t%s\n"
+			"\t%s\n"
+			"\t%s\n"
+		"	dd ibs=\"$blocksize\" obs=512 if=\"$sourcepath\" %s;\n"
+		"	sw_retval=$?\n"
+			"\t%s\n"
+
+		"else\n"
+			"\t%s\n"
+			"\t%s\n"
+		"	sw_retval=1\n"
+		"fi\n"
+
+		"if test \"$sw_retval\" != \"0\"; then\n"
+		"	 sb__delaytime=0;\n"
+		"fi\n"
+		"sleep \"$sb__delaytime\"\n"
+		"%s\n"
+		"%s\n"
+			,
+		SEVENT(2, vlv, SW_SESSION_BEGINS, ""),
+		swicol_subshell_marks(subsh, "source", 'L', nhops, vlv),	
+		strob_str(set_vx),
+		blocksize,
+		dirname,
+		path,
+		sourcepath,
+		delaytime,
+		strob_str(opt2),
+		SEVENT(1, -1, SW_SOURCE_ACCESS_BEGINS, ""),
+		SEVENT(2, vlv, SW_SOURCE_ACCESS_BEGINS, ""),
+		pax_write_command,
+		SEVENT(2, vlv, SW_SOURCE_ACCESS_ENDS, "status=0"),
+		strob_str(opt1),
+		SEVENT(1, -1, SW_SOURCE_ACCESS_BEGINS, ""),
+		SEVENT(2, vlv, SW_SOURCE_ACCESS_BEGINS, ""),
+		strob_str(to_devnull),
+		SEVENT(2, vlv, SW_SOURCE_ACCESS_ENDS, "status=0"),
+		SEVENT(2, vlv, SW_SOURCE_ACCESS_ERROR, strob_str(tmp1)),
+		SEVENT(1, -1, SW_SOURCE_ACCESS_ERROR, strob_str(tmp1)),
+		SEVENT(2, vlv, SW_SOURCE_ACCESS_ERROR, strob_str(tmp1)),
+		SEVENT(1, -1, SW_SOURCE_ACCESS_ERROR, strob_str(tmp1)),
+		strob_str(opt1),
+		SEVENT(1, -1, SW_SOURCE_ACCESS_BEGINS, ""),
+		SEVENT(2, vlv, SW_SOURCE_ACCESS_BEGINS, ""),
+		strob_str(to_devnull),
+		SEVENT(2, vlv, SW_SOURCE_ACCESS_ENDS, "status=0"),
+		SEVENT(2, vlv,  SW_SOURCE_ACCESS_ERROR, strob_str(tmp2)),
+		SEVENT(1, -1, SW_SOURCE_ACCESS_ERROR, strob_str(tmp2)),
+		SEVENT(2, vlv, SW_SESSION_ENDS, "status=$sw_retval"),
+		swicol_subshell_marks(subsh2, "source", 'R', nhops, vlv)
+		);
+
+	free(path);
+	free(dirname);
+	strob_close(tmp);
+	strob_close(tmp1);
+	strob_close(tmp2);
+	if (G->g_source_script_name) {
+		swc_tee_to_file(G->g_source_script_name, strob_str(buffer));
+	}
+	strob_close(buffer);
+	strob_close(opt1);
+	strob_close(opt2);
+	strob_close(set_vx);
+	strob_close(to_devnull);
+	strob_close(subsh);
+	strob_close(subsh2);
+	/*
+	 * 0 is OK
+	 * !0 is error
+	 */
+	return !(ret > 0);
+}
+
+int
+swc_read_target_ctl_message(GB * G, int fd, STROB * control_message, 
+				int vlevel, char * loc)
+{
+	int n;
+	char c[2];
+	int count = 0;
+
+	strob_strcpy(control_message, "");
+	c[1] = '\0';
+	n = read(fd, (void*)&c, 1);
+	if (n == 1) count++;
+	while (n == 1 && c[0] != '\n' && count < MAX_CONTROL_MESG_LEN) {
+		strob_strcat(control_message, c);
+		n = read(fd, (void*)&c, 1);
+		if (n == 1) count ++;
+	}
+	swlib_doif_writef(vlevel, SWC_VERBOSE_IDB, &G->g_logspec, G->g_stderr_fd,
+		"%s control message: %s\n", 
+			loc, strob_str(control_message));
+	if (n == 1 && count == 1) { 
+		return 0;
+	} else if (n == 1 && count < MAX_CONTROL_MESG_LEN) {
+		return count;
+	} else {
+		return -1;
+	}
+}
+
+char *
+swc_get_target_script_pid(GB * G, STROB * control_message)
+{
+	char *s;
+	char *p;
+	char *ed;
+	char *ret;
+
+	s = strob_str(control_message);
+	p = strstr(s, SWBIS_TARGET_CTL_MSG_125);
+	if (!p)
+		return (char*)NULL;
+	if (p != s)
+		return (char*)NULL;
+	p+=strlen(SWBIS_TARGET_CTL_MSG_125);
+	if (*p != ':')
+		return (char*)NULL;
+	p++;
+	if (*p != ' ')
+		return (char*)NULL;
+	p++;
+	ret = strdup(p);
+	if ((ed=strpbrk(ret, "\n\r"))) *ed = '\0';
+	return ret;
+}
+
+int
+swc_read_start_ctl_message(GB * G, int fd, 
+	STROB * control_message, 
+	STRAR * tramp_list, 
+	int vlevel, 
+	char ** pscript_pid, 
+	char * loc)
+{
+	int ret = 0;
+	strob_strcpy(control_message, "");
+
+	while(ret >= 0 &&
+		strstr(strob_str(control_message), SWBIS_TARGET_CTL_MSG_125) == 
+							(char*)NULL
+	) {
+			ret = swc_read_target_ctl_message(G, fd, 
+						control_message, 
+						vlevel, 
+						loc);
+			if (ret >= 0 && strob_strlen(control_message))
+				strar_add(tramp_list, 
+					strob_str(control_message));
+	}
+	if (ret < 0) {
+		return ret;
+	} 
+	*pscript_pid = swc_get_target_script_pid(G, control_message);
+	if (*pscript_pid == (char*)NULL) {
+		/*
+		 * allow this to be OK, A NetBSD PATH=`getconf PATH` sh
+		 * did not support $PPID. Use of the PPID is only needed for
+		 * multiple ssh-hops, and maybe it shouldn't be needed at all.
+		 */
+		ret = 0;
+	} else {
+		swlib_doif_writef(vlevel, SWC_VERBOSE_IDB, &G->g_logspec, G->g_stderr_fd,
+			"remote script pid: %s\n", *pscript_pid);
+		
+	}
+	return ret;
+}
+
+int
+swc_tee_to_file(char * name, char * buf)
+{
+	int ret;
+	int fd;
+	if (!name) return 0;
+	fd = open(name, O_RDWR|O_TRUNC|O_CREAT, 0666);
+	if (fd < 0) return fd;
+	ret = write(fd, buf, strlen(buf));
+	if (ret != (int)strlen(buf)) return -1;
+	close(fd);
+	return ret;
+}
+
+void
+swc_gf_xformat_close(GB * G, XFORMAT * xformat)
+{
+	if (xformat) xformat_close(xformat);
+	G->g_xformat = NULL;
+}
+
+int
+swc_get_stderr_fd(GB * G)
+{
+	return G->g_stderr_fd;
+}
+
+void
+swc_shutdown_logger(GB * G, int signum)
+{
+	int status;	
+	if (G->g_logger_pid > 0) {
+		if (kill(G->g_logger_pid, signum) < 0) {
+			fprintf(stderr, "%s: kill(2): %s\n",
+				swlib_utilname_get(), strerror(errno));
+		}
+	}
+	if (G->g_swevent_fd >= 0) close(G->g_swevent_fd);
+	swlib_doif_writef(G->g_verboseG, SWC_VERBOSE_IDB,
+			&G->g_logspec, swc_get_stderr_fd(G), 
+			"waitpid() on logger_pid [%d]\n", G->g_logger_pid);
+	waitpid(G->g_logger_pid, &status, 0);
+	close(G->g_t_efd);
+	close(G->g_s_efd);
+	swlib_doif_writef(G->g_verboseG, SWC_VERBOSE_IDB,
+			&G->g_logspec, swc_get_stderr_fd(G), 
+			"finished waitpid() on logger_pid [%d]\n", G->g_logger_pid);
+}
+
+void
+swc_set_stderr_fd(GB * G, int fd)
+{
+	G->g_stderr_fd = fd;
+	swutil_set_stderr_fd(G->g_swutil, fd);
+}
+
+void 
+swc_lc_raise(GB * G, char * file, int line, int signo)
+{
+	swlib_doif_writef(G->g_verboseG, SWC_VERBOSE_IDB,
+				&G->g_logspec, swc_get_stderr_fd(G), 
+					"raising signal %d at %s:%d\n",
+						signo, file, line);
+	G->g_signal_flag = signo;
+	raise(signo);
+}
+
+void 
+swc_lc_exit(GB * G, char * file, int line, int status)
+{
+	swlib_doif_writef(G->g_verboseG, SWC_VERBOSE_IDB,
+			&G->g_logspec, swc_get_stderr_fd(G), 
+				"exiting at %s:%d with value %d\n",
+						file, line, status);
+	exit(status);
+}
+
+int
+swc_is_option_true(char * s)
+{
+	if (!s || strcasecmp(s, CHARTRUE)) return 0;
+	return 1;  
+}
+
+int
+sw_exitval(GB * G, int count, int suc)
+{
+	if (suc && count == suc) return 0;
+	if (suc && count) return 2;
+	if (suc == 0) return 1;
+	swlib_doif_writef(G->g_verboseG, G->g_fail_loudly,
+			&G->g_logspec, swc_get_stderr_fd(G),
+			"abnormal exit\n");
+	return 255;
+}
+
+void
+swc_check_for_current_signals(GB * G, int lineno, char * no_remote_kill)
+{
+	switch(G->g_signal_flag) {
+		case SIGTERM:
+		case SIGPIPE:
+		case SIGINT:
+			swlib_doif_writef(G->g_verboseG,
+				SWC_VERBOSE_IDB, &G->g_logspec, swc_get_stderr_fd(G),
+			"swc_check_for_current_signals: line=%d Got signal %d.\n",
+					 	lineno, G->g_signal_flag);
+			swgp_signal_block(SIGTERM, (sigset_t *)NULL);
+			swgp_signal_block(SIGINT, (sigset_t *)NULL);
+			swgp_signal_block(SIGPIPE, (sigset_t *)NULL);
+			if (!swc_is_option_true(no_remote_kill)) {
+				swc_do_run_kill_cmd((SHCMD*)(NULL), 
+						G->g_target_kmd, 
+						G->g_source_kmd, 
+						G->g_verboseG);
+			} else {
+				swlib_doif_writef(G->g_verboseG, 
+						SWC_VERBOSE_IDB,
+						&G->g_logspec, swc_get_stderr_fd(G),
+			"swc_check_for_current_signals:  not running kill cmds.\n");
+			}
+			(*(G->g_main_sig_handler))(G->g_signal_flag);
+			break;
+	}
+}
+
+pid_t
+swc_run_source_script(GB * G,
+		int swutil_x_mode, 
+		int local_stdin, 
+		int source_pipe,
+		char * source_path,
+		int nhops,
+		char * pax_write_command_key,
+		sigset_t *fork_blockmask,
+		sigset_t *fork_defaultmask,
+		char * hostname,
+		char * blocksize,
+		int verbose_threshold
+		) 
+{
+	pid_t write_pid;
+
+	if ((swutil_x_mode == 0 || local_stdin)) {
+		/*
+		* fork not required.
+		*/
+		return 0;
+	}
+
+	write_pid = swndfork(fork_blockmask, fork_defaultmask);
+	if (write_pid == 0) {
+		int ret_source = 0;
+		/*
+		 * Write the source scripts.
+		 */
+		if (swutil_x_mode && local_stdin == 0) {
+			/*
+			* If source is remote.
+			*/
+			swlib_doif_writef(G->g_verboseG, SWC_VERBOSE_IDB2, 
+					&G->g_logspec,
+					swc_get_stderr_fd(G), 
+					"running source script.\n");
+			ret_source = swc_write_source_copy_script(G,
+				source_pipe, 
+				source_path,
+				SWINSTALL_DO_SOURCE_CTL_MESSAGE,
+				verbose_threshold /*SWC_VERBOSE_4*/, 
+				SWC_SCRIPT_SLEEP_DELAY, 
+				nhops,
+				pax_write_command_key,
+				hostname,
+				blocksize);
+			swlib_doif_writef(G->g_verboseG, SWC_VERBOSE_IDB2,
+					&G->g_logspec, swc_get_stderr_fd(G),
+				"Source script finished return value=%d.\n",
+								ret_source);
+
+		} else {
+			swlib_doif_writef(G->g_verboseG, G->g_fail_loudly, 
+							&G->g_logspec, swc_get_stderr_fd(G),
+					"Unexpected Dead code excpeption\n");
+			swlib_doif_writef(G->g_verboseG,
+					SWC_VERBOSE_IDB2, &G->g_logspec, swc_get_stderr_fd(G), 
+		"NOT running source script in child, exiting with %d.\n",
+								ret_source);
+			LCEXIT(1);
+		}
+		/*
+		 * 0 is OK
+		 * !0 is error
+		 */
+		_exit(ret_source);
+	} else if (write_pid < 0) {
+		swlib_doif_writef(G->g_verboseG, G->g_fail_loudly,
+				&G->g_logspec, swc_get_stderr_fd(G),
+					"fork error : %s\n", strerror(errno));
+	}
+	return write_pid;
+}
+
+void
+swc_helptext_target_syntax(FILE * fp)
+{
+fprintf(fp, "%s",
+"\n"
+"Target Syntax:\n"
+);
+
+fprintf(fp, "%s",
+"   software_selections   Refer to the software objects (products, filesets)\n"
+"                         on which to be operated. (Not yet implemented)\n"
+"   target    Refers to the software_collection where the software\n"
+"             selections are to be applied.\n"
+"             Target follows syntax of Section 4.1.4.2 (Source and Target\n"
+"             Specification and Logic) summarized as follows:\n"
+"\n"
+"       target : HOST_CHARACTER_STRING ':' PATHNAME_CHARACTER_STRING\n"
+"              | HOST_CHARACTER_STRING ':'\n"
+"              | HOST_CHARACTER_STRING \n"
+"              | PATHNAME_CHARACTER_STRING \n"
+"              ; \n"
+"\n"
+"       PATHNAME_CHARACTER_STRING must be an absolute path unless the\n"
+"                                 target has a HOST_CHARACTER_STRING\n"
+"                                 in which case it may be a relative path.\n"
+"       HOST_CHARACTER_STRING is an IP or hostname or '-'\n"
+"          NOTE: A '-' indicating standard output is an implementation\n"
+"                    extension.\n"
+);
+
+fprintf(fp , "%s",
+"\n"
+"Implementation Extension Target Syntax:\n"
+"    Syntax:\n"
+"    %start   xtarget    # the Implementation Extension Target\n"
+"    xtarget   : xtarget DELIM sshtarget\n"
+"              | sshtarget\n"
+"              ; \n"
+"    sshtarget : user '@' target\n"
+"              | target\n"
+"              | user '@'\n"
+"    DELIM     : @@\n"
+"\n"
+);
+}
+
+int
+swc_get_catalog_path(STROB * control_message,
+	char * installed_software_catalog)
+{
+	char * s;
+	char * p;
+	char * isc;
+
+	s = strstr(strob_str(control_message),
+		SWBIS_TARGET_CTL_MSG_128);
+	if (!s) return -2;
+	s = strchr(strob_str(control_message), ':');
+	if (!s) return -3;
+	s++;
+	while(*s == ' ') s++;
+	while(*s == '/') s++;
+
+	if (*installed_software_catalog == '/')
+		isc = installed_software_catalog + 1;
+	else
+		isc = installed_software_catalog;
+
+	if (strstr(s, isc) != s) {
+		return -4;
+	}
+
+	p = strob_str(control_message);
+	memmove(p, s, strlen(s) + 1);
+	return 0;
+}
+
+int
+swc_read_catalog_ctl_message(GB * G, int fd,
+	STROB * control_message, 
+	int vlevel, 
+	char * loc,
+	char * installed_software_catalog)
+{
+	int ret = 0;
+	strob_strcpy(control_message, "");
+
+	while(ret >= 0 &&
+		strstr(strob_str(control_message),
+			SWBIS_TARGET_CTL_MSG_128) == (char*)NULL
+	) {
+		ret = swc_read_target_ctl_message(G, fd,
+					control_message,
+					vlevel,
+					loc);
+	}
+	if (ret < 0) {
+		return ret;
+	} 
+	ret = swc_get_catalog_path(control_message, installed_software_catalog);
+	return ret;
+}
+
+int 
+swc_wait_on_script(GB * G, pid_t write_pid, char * location)
+{
+	/*
+	 * wait on the write_script process and check for errors.
+	 */
+	pid_t ret;
+	int status;
+	ret = waitpid(write_pid, &status, 0);
+	if (ret < 0) {
+		swlib_doif_writef(G->g_verboseG, G->g_fail_loudly,
+				&G->g_logspec, swc_get_stderr_fd(G),
+			"%s scripts waitpid : %s\n", 
+			location, strerror(errno));
+		return -1;
+	}
+	if (WIFEXITED(status)) {
+		return (int)(WEXITSTATUS(status));
+	} else {
+		swlib_doif_writef(G->g_verboseG, G->g_fail_loudly, &G->g_logspec,
+			swc_get_stderr_fd(G),
+			"%s script had abnormal exit.\n", 
+			location);
+		return -2;
+	}
+}
+
