@@ -31,6 +31,9 @@
 #endif
 
 volatile int global_lastsig;
+
+#define PAX_READ_COMMANDS_LEN	10
+#define PAX_WRITE_COMMANDS_LEN	10
 #define SW_UTILNAME		"swutility"
 #define REPORT_BUGS		"<bug-swbis@gnu.org>"
 #define SWC_PID_ARRAY_LEN	30
@@ -51,6 +54,27 @@ volatile int global_lastsig;
 #define SWBIS_TARGET_CTL_MSG_128 	"128 catalog path determined"
 #define SWBIS_TARGET_CTL_MSG_508 	"508 target script error"
 
+#define SWINSTALL_DO_SOURCE_CTL_MESSAGE		(swutil_x_mode && local_stdin == 0)
+#define SWBIS_SWINSTALL_SOURCE_CTL_ARCHIVE	"130 source is from archive"
+#define SWBIS_SWINSTALL_SOURCE_CTL_DIRECTORY 	"140 source is from directory"
+
+#define SWCOPY_DO_SOURCE_CTL_MESSAGE		(swutil_x_mode && local_stdin == 0)
+#define SWBIS_SWCOPY_SOURCE_CTL_ARCHIVE		"130 source is from archive"
+#define SWBIS_SWCOPY_SOURCE_CTL_DIRECTORY 	"140 source is from directory"
+
+
+#define SWPARSE_AT_LEVEL	0
+#define VERBOSE_LEVEL2		2
+#define VERBOSE_LEVEL3		3
+#define LCEXIT(arg)		swc_lc_exit(G, __FILE__, __LINE__, arg)
+#define LC_RAISE(arg)		swc_lc_raise(G, __FILE__, __LINE__, arg)
+#define LOCAL_RSH_BIN 			"rsh"
+#define REMOTE_RSH_BIN 			"rsh"
+#define LOCAL_SSH_BIN 			"ssh"
+#define REMOTE_SSH_BIN 			"ssh"
+#define SWC_PID_ARRAY_LEN			30
+#define MAX_CONTROL_MESG_LEN			2000
+
 struct g_pax_write_command {
 	char * idM;
 	char * commandM;
