@@ -33,8 +33,9 @@
 #include "swutilname.h"
 #include "swi.h"
 #include "swicol.h"
+#include "globalblob.h"
 
-#define KILL_PID		SWSSH_TRACK_PID
+/* #define KILL_PID		SWSSH_TRACK_PID */
 
 #ifndef DEFAULT_PAX_W 
 #define DEFAULT_PAX_W "pax"
@@ -50,9 +51,7 @@ typedef struct {
 } SCARY;
 
 int sw_main_get_stderr_fd(void);
-int swinstall_write_target_install_script(
-		int ofd, 
-		char * fp_targetpath, 
+int swinstall_write_target_install_script(GB * , int ofd, char * fp_targetpath, 
 		STROB * control_message, 
 		char * sourcepath,
 		int delaytime,
@@ -68,13 +67,14 @@ int swinstall_write_target_install_script(
 		struct sw_logspec * swlogspec
 		);
 
-int swinstall_arfinstall(SWI * swi, int ofd, int efd, int do_preview,
+int swinstall_arfinstall(GB * , SWI * swi, int ofd, int efd,
 	int * deadman, char * target_path, char * catalog_path,
 	VPLOB * swspecs, int section, int altofd, int opt_preview,
 	char * pax_read_command, int alt_catalog_root, int event_fd,
 	struct extendedOptions * eopt,
 	struct sw_logspec * swlogspec, int keep_old_files, unsigned long int *);
 
-int swinstall_get_utsname_attributes(SWI * swi, int ofd, int event_fd);
+int swinstall_get_utsname_attributes(GB * , SWI * swi, int ofd, int event_fd);
+int swinstall_lib_write_trailer_blocks(int ofd, int nblocks);
 
 #endif
