@@ -54,25 +54,11 @@
 #include "atomicio.h"
 #include "swutilname.h"
 
-#include "debug_config.h"
-#ifdef SWINSTALLNEEDDEBUG
-#define SWINSTALL_E_DEBUG(format) SWBISERROR("SWINSTALL DEBUG: ", format)
-#define SWINSTALL_E_DEBUG2(format, arg) SWBISERROR2("SWINSTALL DEBUG: ", format, arg)
-#define SWINSTALL_E_DEBUG3(format, arg, arg1) SWBISERROR3("SWINSTALL DEBUG: ", format, arg, arg1)
-#else
-#define SWINSTALL_E_DEBUG(arg)
-#define SWINSTALL_E_DEBUG2(arg, arg1)
-#define SWINSTALL_E_DEBUG3(arg, arg1, arg2)
-#endif /* SWINSTALLNEEDDEBUG */
-
 extern struct g_pax_read_command g_pax_read_commands[];
 
 /*
  * These are required by the TEVENTS routine
  */
-extern struct swEvents eventsArray[];
-static struct swEvents * g_evnt = eventsArray;
-
 
 #define SWBIS_DEFAULT_REVISION "0.0"
 
@@ -81,8 +67,6 @@ static struct swEvents * g_evnt = eventsArray;
 /*  Array of scripts that must be run */
 static SCARY * g_script_array[SCARY_ARRAY_LEN+1];
 
-int get_stderr_fd(void);
-
 /** -------------------------------------- */
 
 static
@@ -201,7 +185,7 @@ scary_find_script(SCARY ** array, char * tag, char * tagspec)
 
 static
 void
-audit_execution_scripts(SWI * swi, SCARY ** scary_scripts)
+audit_execution_scripts(GB * G, SWI * swi, SCARY ** scary_scripts)
 {
 	SWI_PRODUCT * product;
 	SWI_XFILE * fileset;
@@ -287,7 +271,7 @@ swinstall_lib_write_trailer_blocks(int ofd, int nblocks)
 
 static
 int
-write_control_script_code_fragment(SWI * swi, SWI_CONTROL_SCRIPT * script, char * swspec_tags, STROB * buf)
+write_control_script_code_fragment(GB * G, SWI * swi, SWI_CONTROL_SCRIPT * script, char * swspec_tags, STROB * buf)
 {
 	STROB * tmp;
 	
@@ -411,7 +395,7 @@ write_single_file_tar_archive(SWI * swi, int ofd, char * name, char * data)
 
 static
 int
-load_single_file_tar_archive (
+load_single_file_tar_archive (GB * G,
 	SWI * swi,
 	int ofd, 
 	char * catalog_path,
@@ -522,7 +506,7 @@ load_single_file_tar_archive (
 
 static
 int
-write_tar_installed_software_index_file (SWI * swi, int ofd,
+write_tar_installed_software_index_file (GB * G, SWI * swi, int ofd,
 	char * catalog_path,
 	char * pax_read_command,
 	int alt_catalog_root,
@@ -546,7 +530,7 @@ write_tar_installed_software_index_file (SWI * swi, int ofd,
 	strob_strcpy(name, swi->swi_pkgM->catalog_entryM);
 	swlib_unix_dircat(name, SW_A_INSTALLED);
 
-	ret = load_single_file_tar_archive(
+	ret = load_single_file_tar_archive(G,
 		swi,
 		ofd, 
 		catalog_path,
@@ -564,7 +548,7 @@ write_tar_installed_software_index_file (SWI * swi, int ofd,
 
 static
 int
-construct_script(STROB * buf, SWI * swi, 
+construct_script(GB * G, STROB * buf, SWI * swi, 
 		SWI_CONTROL_SCRIPT * script, 
 		char * tagspec,
 		int error_event_value,
@@ -582,7 +566,7 @@ construct_script(STROB * buf, SWI * swi,
 	 * write main script fragment
 	 */
 
-	ret = write_control_script_code_fragment(swi, script, tagspec, buf);
+	ret = write_control_script_code_fragment(G, swi, script, tagspec, buf);
 	SWLIB_ASSERT(ret == 0);
 
 	/*
@@ -631,7 +615,7 @@ construct_script(STROB * buf, SWI * swi,
 
 static
 int
-construct_prepost_script(STROB * buf, SWI * swi, char * script_tag)
+construct_prepost_script(GB * G, STROB * buf, SWI * swi, char * script_tag)
 {
 	STROB * tmp;
 	SWI_PRODUCT * product;
@@ -694,7 +678,7 @@ construct_prepost_script(STROB * buf, SWI * swi, char * script_tag)
 			"# generated by swinstall_lib.c:construct_execution_script\n",
 			"cd \"%s\"\n",
 			swi->swi_pkgM->target_pathM);
-		construct_script(buf, swi,
+		construct_script(G, buf, swi,
 			product_xxinstall_script,
 			product->baseM.tagM,
 			event_error_value,
@@ -717,7 +701,7 @@ construct_prepost_script(STROB * buf, SWI * swi, char * script_tag)
 
 		strob_sprintf(tmp, 0, "%s.%s", product->baseM.tagM, fileset->baseM.tagM);
 		strob_sprintf(buf, STROB_DO_APPEND, "\tcd \"%s\"\n", swi->swi_pkgM->target_pathM);
-		construct_script(buf, swi,
+		construct_script(G, buf, swi,
 			fileset_xxinstall_script,
 			strob_str(tmp),
 			event_error_value,
@@ -735,7 +719,7 @@ construct_prepost_script(STROB * buf, SWI * swi, char * script_tag)
 
 static
 int
-construct_analysis_script(STROB * buf, SWI * swi, SWI_CONTROL_SCRIPT ** p_script)
+construct_analysis_script(GB * G, STROB * buf, SWI * swi, SWI_CONTROL_SCRIPT ** p_script)
 {
 	int ret;
 	SWI_PRODUCT * prod;
@@ -759,7 +743,7 @@ construct_analysis_script(STROB * buf, SWI * swi, SWI_CONTROL_SCRIPT ** p_script
 	
 		script = swi_product_get_control_script_by_tag(prod, SW_A_checkinstall);
 		SWLIB_ASSERT(script != NULL);
-		ret = write_control_script_code_fragment(swi, script, prod->baseM.tagM, buf);
+		ret = write_control_script_code_fragment(G, swi, script, prod->baseM.tagM, buf);
 		SWLIB_ASSERT(ret == 0);
 
 		/*
@@ -811,7 +795,7 @@ construct_analysis_script(STROB * buf, SWI * swi, SWI_CONTROL_SCRIPT ** p_script
 
 static
 int
-construct_controlsh_script(STROB * buf, SWI * swi)
+construct_controlsh_script(GB * G, STROB * buf, SWI * swi)
 {
 	char * tag;
 	STROB * tmp;
@@ -900,7 +884,7 @@ construct_controlsh_script(STROB * buf, SWI * swi)
 
 static
 int
-write_tar_controlsh_file(SWI * swi, int ofd,
+write_tar_controlsh_file(GB * G, SWI * swi, int ofd,
 	char * catalog_path,
 	char * pax_read_command,
 	int alt_catalog_root,
@@ -917,10 +901,10 @@ write_tar_controlsh_file(SWI * swi, int ofd,
 
 	strob_strcpy(name, swi->swi_pkgM->catalog_entryM);
 	swlib_unix_dircat(name, SW_A_controlsh);
-	ret = construct_controlsh_script(data, swi);
+	ret = construct_controlsh_script(G, data, swi);
 	SWLIB_ASSERT(ret == 0);
 
-	ret = load_single_file_tar_archive(
+	ret = load_single_file_tar_archive(G,
 		swi,
 		ofd, 
 		catalog_path,
@@ -938,7 +922,7 @@ write_tar_controlsh_file(SWI * swi, int ofd,
 
 static
 int
-write_tar_session_options_file(SWI * swi, int ofd,
+write_tar_session_options_file(GB * G, SWI * swi, int ofd,
 	char * catalog_path,
 	char * pax_read_command,
 	int alt_catalog_root,
@@ -956,7 +940,7 @@ write_tar_session_options_file(SWI * swi, int ofd,
 	write_session_options_filename(name, swi);
 	write_session_options_file(data, swi);
 
-	ret = load_single_file_tar_archive(
+	ret = load_single_file_tar_archive(G,
 		swi,
 		ofd, 
 		catalog_path,
@@ -1322,7 +1306,7 @@ int
 write_out_signature_member(SWI * swi, struct tar_header * ptar_hdr,
 		struct new_cpio_header * file_hdr,
 		int ofd, int startoffset,
-		int endoffset, int opt_preview, int signum,
+		int endoffset, int signum,
 		int *package_ret)
 {
 	int ifd;
@@ -1400,28 +1384,24 @@ write_out_signature_member(SWI * swi, struct tar_header * ptar_hdr,
 	if (etar_set_pathname(etar, strob_str(tmp))) SWLIB_FATAL("name too long");
 	etar_set_chksum(etar);
 
-	if (opt_preview == 0) {
-		ret = write(ofd, (void*)(etar_get_hdr(etar)), TARRECORDSIZE);
-		if (ret != TARRECORDSIZE) {
-			SWI_internal_fatal_error();
-		}
-		retval += ret;
-
-		if (siglen <= 512)
-			filesize = 512;
-		else if (siglen <= 1024)
-			filesize = 1024;
-		else
-			SWI_internal_fatal_error();
-		
-		ret = atomicio((ssize_t (*)(int, void *, size_t))write,
-				ofd, (void*)(sig), filesize);
-		if (ret != (int)filesize) 
-			SWI_internal_fatal_error();
-		retval += ret;
-	} else {
-		;
+	ret = write(ofd, (void*)(etar_get_hdr(etar)), TARRECORDSIZE);
+	if (ret != TARRECORDSIZE) {
+		SWI_internal_fatal_error();
 	}
+	retval += ret;
+
+	if (siglen <= 512)
+		filesize = 512;
+	else if (siglen <= 1024)
+		filesize = 1024;
+	else
+		SWI_internal_fatal_error();
+	
+	ret = atomicio((ssize_t (*)(int, void *, size_t))write,
+			ofd, (void*)(sig), filesize);
+	if (ret != (int)filesize) 
+		SWI_internal_fatal_error();
+	retval += ret;
 
 	etar_close(etar);
 	strob_close(tmp);
@@ -1434,7 +1414,7 @@ int
 write_out_all_signatures(SWI * swi, struct tar_header * ptar_hdr,
 		struct new_cpio_header * file_hdr,
 		int ofd, int startoffset,
-		int endoffset, int do_preview, unsigned long filesize)
+		int endoffset, unsigned long filesize)
 {
 	int curpos;
 	int ifd;
@@ -1501,7 +1481,7 @@ write_out_all_signatures(SWI * swi, struct tar_header * ptar_hdr,
 		ret = write_out_signature_member(swi, ptar_hdr,
 				file_hdr, ofd,
 				startoffset, endoffset,
-				do_preview, sig_number--, &package_ret);
+				sig_number--, &package_ret);
 		if (ret < 0) return ret;
 		package_current += package_ret;
 		current += ret;
@@ -1765,7 +1745,7 @@ send_signature_files(SWI * swi, int ofd,
 	int alt_catalog_root, int event_fd,
 	struct tar_header * ptar_hdr,
 	int sig_block_start, int sig_block_end,
-	int do_preview, unsigned long filesize)
+	unsigned long filesize)
 {
 	int ret = 0;
 	int padamount;
@@ -1836,8 +1816,7 @@ send_signature_files(SWI * swi, int ofd,
 	 */
 	
 	ret = write_out_all_signatures(swi, tar_hdr, file_hdr,
-		ofd, sig_block_start, sig_block_end,
-		do_preview, filesize);
+		ofd, sig_block_start, sig_block_end, filesize);
 
 	if (ret < 0) {
 		SWBIS_ERROR_IMPL();
@@ -2272,7 +2251,7 @@ send_catalog_tarfile(SWI * swi, int ofd,
 
 static
 int
-run_analysis_script(SWI * swi, int ofd, int event_fd)
+run_analysis_script(GB * G, SWI * swi, int ofd, int event_fd)
 {
 	int ret;
 	STROB * buf;
@@ -2286,7 +2265,7 @@ run_analysis_script(SWI * swi, int ofd, int event_fd)
 	buf = strob_open(400);
 	idtmp = strob_open(100);
 
-	ret = construct_analysis_script(buf, swi, &script);
+	ret = construct_analysis_script(G, buf, swi, &script);
 	SWLIB_ASSERT(ret == 0);
 	
 	strob_sprintf(idtmp, 0, "analysis phase 2");
@@ -2342,7 +2321,6 @@ run_analysis_script(SWI * swi, int ofd, int event_fd)
 
 		script_status = swicol_rpsh_get_event_status(swi->swicolM, NULL, SW_CONTROL_SCRIPT_ENDS, this_index, &this_index);
 		script->resultM = script_status;
-		/* fprintf(stderr, "JLJL [%s] status=%d\n", checkinstall_message, script_status); */
 	} else {
 		/*
 		 * This is OK
@@ -2357,7 +2335,7 @@ run_analysis_script(SWI * swi, int ofd, int event_fd)
 }
 
 int
-swinstall_get_utsname_attributes(SWI * swi, int ofd, int event_fd)
+swinstall_get_utsname_attributes(GB * G, SWI * swi, int ofd, int event_fd)
 {
 	int ret;
 	STROB * tmp = strob_open(10);
@@ -2415,7 +2393,6 @@ swinstall_get_utsname_attributes(SWI * swi, int ofd, int event_fd)
 	E_DEBUG2("utsname=[%s]", strob_str(tmp));
 
 	if (ret != 0) {
-		;
 		/*
 		 * Examine the events in swicol->evemt_listM to determine
 		 * what action to take
@@ -2434,7 +2411,7 @@ swinstall_get_utsname_attributes(SWI * swi, int ofd, int event_fd)
 
 static
 int
-construct_execution_phase_script(SWI * swi,
+construct_execution_phase_script(GB * G, SWI * swi,
 			STROB * buf,
 			char * pax_read_command
 			)
@@ -2456,7 +2433,7 @@ construct_execution_phase_script(SWI * swi,
 	/*
 	 * construct the preinstall portion of the execution script
 	 */
-	ret = construct_prepost_script(buf, swi, SW_A_preinstall);
+	ret = construct_prepost_script(G, buf, swi, SW_A_preinstall);
 
 	strob_sprintf(buf, STROB_DO_APPEND,
 	"exit \"$sw_retval\"\n"
@@ -2498,7 +2475,7 @@ construct_execution_phase_script(SWI * swi,
 	"(\n"
 	);
 	
-	ret = construct_prepost_script(buf, swi, SW_A_postinstall);
+	ret = construct_prepost_script(G, buf, swi, SW_A_postinstall);
 
 	strob_sprintf(buf, STROB_DO_APPEND,
 	"exit \"$sw_retval\"\n"
@@ -2514,9 +2491,32 @@ construct_execution_phase_script(SWI * swi,
 	return 0;
 }
 
+int
+determine_tar_listing_verbose_level(SWI * swi)
+{
+	int taru_ls_verbose_level;
+
+	if (swi->swc_idM == SWC_U_I /* swinstall */) {
+		if (swi->verboseM >= SWC_VERBOSE_4) {
+			taru_ls_verbose_level = 1;
+		} else {
+			taru_ls_verbose_level = 0;
+		}
+	} else if (swi->swc_idM == SWC_U_L /* swlist */) {
+		if (swi->verboseM >= SWC_VERBOSE_2) {
+			taru_ls_verbose_level = 1;
+		} else {
+			taru_ls_verbose_level = 0;
+		}
+	} else {
+		taru_ls_verbose_level = 0;
+	}
+	return taru_ls_verbose_level;
+}
+
 static
 int
-arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
+arfinstall_tar(GB * G, SWI * swi, int ofd, int efd,
 	int * deadman, char * target_path, char * catalog_path, VPLOB * swspecs,
 	int section, int altofd, int opt_preview,
 	char * pax_read_command_key, int alt_catalog_root, int event_fd,
@@ -2551,6 +2551,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	STROB * newnamebuf;
 	STROB * catalogdir;
 	STROB * tmp;
+	STROB * tmp2;
 	STROB * pathtmp;
 	STROB * tmp_swpath_ex;
 	STROB * execution_phase_script;
@@ -2594,6 +2595,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	tmp_swpath_ex = strob_open(100);
 	namebuf = strob_open(100);
 	tmp = strob_open(10);
+	tmp2 = strob_open(10);
 	pathtmp = strob_open(10);
 	resolved_path = strob_open(10);
 	execution_phase_script = strob_open(10);
@@ -2751,7 +2753,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	while ((read_header_ret = xformat_read_header(xformat)) > 0 &&
 			(!deadman || (deadman && *deadman == 0))) {
 		
-		SWINSTALL_E_DEBUG("HERE");
+		E_DEBUG("HERE");
 		if (xformat_is_end_of_archive(xformat)){
 			/*
 			 * This is an unexpected error
@@ -2807,7 +2809,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			/*
 			 * Examine the catalog for signature.
 			 */
-			SWINSTALL_E_DEBUG("HERE");
+			E_DEBUG("HERE");
 			did_catalog_tar = 1;
 			swi_examine_signature_blocks(swi->swi_pkgM->dfilesM,
 					&sig_block_start, &sig_block_end);
@@ -2854,7 +2856,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			 * there are no signatures.
 			 * =====================================
 			 */
-			SWINSTALL_E_DEBUG("HERE");
+			E_DEBUG("HERE");
 			did_sigfiles = 1;
 			if (opt_preview == 0) {
 				/* TS_sig_load */
@@ -2878,7 +2880,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			 *	 <catalog_path>/export/catalog.tar.sig
 			 *	 <catalog_path>/export/catalog.tar.sigN
 			 */
-			SWINSTALL_E_DEBUG("HERE");
+			E_DEBUG("HERE");
 			did_sigfiles = 1;
 			filesize = xformat_get_filesize(xformat);	
 
@@ -2888,7 +2890,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 				ret = send_signature_files(swi, vofd,
 					catalog_path, pax_read_command,
 					alt_catalog_root, event_fd, ptar_hdr,
-					sig_block_start, sig_block_end, 0, filesize);
+					sig_block_start, sig_block_end, filesize);
 			}
 
 			if (ret < 0) {
@@ -2911,7 +2913,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			 * Read past the remainder of the catalog files.
 			 * =====================================
 			 */
-			SWINSTALL_E_DEBUG("HERE");
+			E_DEBUG("HERE");
 			ret = xformat_copy_pass(xformat, swi->nullfdM, ifd);
 			if (ret < 0) {
 				SWBIS_ERROR_IMPL();
@@ -2920,17 +2922,17 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			/*
 			 * Now ready to deal with the storage section.
 			 */		
-			SWINSTALL_E_DEBUG("HERE");
+			E_DEBUG("HERE");
 			break;
 		}
 	} /* while */
 
-	SWINSTALL_E_DEBUG("HERE");
+	E_DEBUG("HERE");
 	if (read_header_ret < 0) {
 		SWBIS_ERROR_IMPL();
 		return -50;
 	}
-	SWINSTALL_E_DEBUG("HERE");
+	E_DEBUG("HERE");
 
 	/*
 	 * Good, made it this far..
@@ -2946,7 +2948,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	 */
 
 	if (opt_preview == 0) {
-		SWINSTALL_E_DEBUG("HERE");
+		E_DEBUG("HERE");
 		/* TS_catalog_unpack */
 		ret = unpack_catalog_tarfile(swi, vofd, catalog_path, pax_read_command, alt_catalog_root, event_fd);
 		if (ret) retval ++;
@@ -2961,8 +2963,8 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 
 	if (opt_preview == 0) {
 		/* TS_session_options */
-		SWINSTALL_E_DEBUG("HERE");
-		ret = write_tar_session_options_file(
+		E_DEBUG("HERE");
+		ret = write_tar_session_options_file(G,
 			swi,
 			vofd,
 			catalog_path,
@@ -2983,8 +2985,8 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 
 	if (opt_preview == 0) {
 		/* TS_load_controlsh */
-		SWINSTALL_E_DEBUG("HERE");
-		ret = write_tar_controlsh_file(
+		E_DEBUG("HERE");
+		ret = write_tar_controlsh_file(G,
 			swi,
 			vofd,
 			catalog_path,
@@ -3001,8 +3003,8 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 		/*
 		 * TS_analysis_002
 		 */
-		SWINSTALL_E_DEBUG("HERE");
-		ret = run_analysis_script(swi, vofd, event_fd);
+		E_DEBUG("HERE");
+		ret = run_analysis_script(G, swi, vofd, event_fd);
 		if (ret) retval ++;
 	}
 
@@ -3018,12 +3020,12 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 		/*
 		 * Audit the control_scripts that must be run
 		 */
-		SWINSTALL_E_DEBUG("HERE");
-		audit_execution_scripts(swi, g_script_array);
+		E_DEBUG("HERE");
+		audit_execution_scripts(G, swi, g_script_array);
 		
 		update_fileset_state(swi, "*", SW_STATE_TRANSIENT);
 
-		ret = write_tar_installed_software_index_file(swi,
+		ret = write_tar_installed_software_index_file(G, swi,
 			vofd,
 			catalog_path,
 			pax_read_command,
@@ -3038,7 +3040,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	 * Send the task script for the fileset.
 	 * =======================================
 	 */
-	SWINSTALL_E_DEBUG("HERE");
+	E_DEBUG("HERE");
 	did_fileset = 1;	
 	strob_strcpy(newnamebuf, target_path);
 	strob_sprintf(tmp, 0,
@@ -3051,8 +3053,8 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	ret = 0;
 	if (opt_preview == 0) {
 		/* TS_execution_phase */
-		SWINSTALL_E_DEBUG("HERE");
-		ret = construct_execution_phase_script(swi,
+		E_DEBUG("HERE");
+		ret = construct_execution_phase_script(G, swi,
 				 execution_phase_script,
 				pax_read_command);
 		ret = swicol_rpsh_task_send_script(
@@ -3065,7 +3067,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	}
 
 	if (ret < 0) {
-		SWINSTALL_E_DEBUG("HERE");
+		E_DEBUG("HERE");
 		return -1;
 	}
 
@@ -3084,7 +3086,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 		 * has just been read.  This happens with HP-UX
 		 * packages.
 		 */
-		SWINSTALL_E_DEBUG("HERE HP style package");
+		E_DEBUG("HERE HP style package");
 		if (uxfio_lseek(ifd, -512, SEEK_CUR) < 0) {
 			SWI_internal_fatal_error();
 		}
@@ -3100,7 +3102,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 		xformat_read_header(xformat) > 0 &&
 		(!deadman || (deadman && *deadman == 0))
 	) {
-		SWINSTALL_E_DEBUG("HERE: Storage");
+		E_DEBUG("HERE: Storage");
 		if (xformat_is_end_of_archive(xformat)){
 			break;
 		}
@@ -3139,23 +3141,23 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			 * current position of the infoheader.
 			 * This is an optimization path.
 			 */
-			SWINSTALL_E_DEBUG("HERE: Storage");
+			E_DEBUG("HERE: Storage");
 			obj = swheader_get_object_by_tag(infoheader, SW_OBJ_file, current_path);
 		} else {
 			/*
 			 * this is the failsafe code path
 			 */
-			SWINSTALL_E_DEBUG("HERE: Storage");
+			E_DEBUG("HERE: Storage");
 			obj = (char*)NULL;
 		}	
 
 		if (obj == (char*)(NULL)) {
-			SWINSTALL_E_DEBUG("HERE: Storage");
+			E_DEBUG("HERE: Storage");
 			swheader_reset(infoheader);
 		}
 	
 		if (current_path && strlen(current_path)) {
-			SWINSTALL_E_DEBUG("HERE: Storage");
+			E_DEBUG("HERE: Storage");
 			if (obj == (char*)NULL) {
 				obj = swheader_get_object_by_tag(infoheader, SW_OBJ_file, current_path);
 			}
@@ -3287,7 +3289,6 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			if (sanity_compare(xformat_ahs_object(xformat), 
 					info_ahs2,
 					swpath_get_pathname(swpath), swi->verboseM >= SWC_VERBOSE_5)) {
-				/* retval++; */
 				cmpret++;
 			}
 
@@ -3432,18 +3433,20 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 				if (log_level >= 2 && logspec->logfdM >= 0) {
 					do_write_at_level = 1;
 				}
-				
-				if (swi->verboseM > SWC_VERBOSE_4) {
-					taru_ls_verbose_level = 2;
-				} else {
-					taru_ls_verbose_level = 1;
-				}
+			
+				taru_ls_verbose_level = determine_tar_listing_verbose_level(swi);	
 
 				taru_print_tar_ls_list(tmp,
 					ahs_vfile_hdr(xformat_ahs_object(xformat)),
 					taru_ls_verbose_level);
-				swlib_doif_writef(swi->verboseM, do_write_at_level,
-					logspec, efd, "%s", strob_str(tmp));
+	
+				if (swi->swc_idM == SWC_U_L) {
+					/* swlist utility */
+					uxfio_write(efd, strob_str(tmp), strob_strlen(tmp));
+				} else {
+					swlib_doif_writef(swi->verboseM, do_write_at_level,
+						logspec, efd, "%s", strob_str(tmp));
+				}
 			}
 
 	
@@ -3476,14 +3479,14 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 			/*
 			 * This code path occurs for storage section control directories.
 			 */	
-			SWINSTALL_E_DEBUG("HERE: Storage");
+			E_DEBUG("HERE: Storage");
 			ret = 0;
 		}
 		optacc_a = 0;
 		if (ret < 0) {
 			SWBIS_ERROR_IMPL();
 		}
-		SWINSTALL_E_DEBUG("HERE: Storage");
+		E_DEBUG("HERE: Storage");
 	} /* while */
 
 	if (cmpret) {
@@ -3552,14 +3555,19 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 		update_execution_script_results(swi, swi->swicolM, g_script_array);
 
 	} else {
-		/*
-	 	 * This satisfies the preview task shell
-		 * which serves to make the script wait until
-		 * it receives this script.
-		 */
-		/* TS_preview */
-		ret = send_nothing_and_wait(swi, ofd, event_fd, "preview task", SWICOL_TL_18, SW_SUCCESS);
-		if (ret) retval ++;
+		if (retval == 0 &&
+		    swi->swc_idM == SWC_U_I && /* swinstall utility */
+		    1
+		) {
+			/*
+		 	 * This satisfies the preview task shell
+			 * which serves to make the script wait until
+			 * it receives this script.
+			 */
+			/* TS_preview */
+			ret = send_nothing_and_wait(swi, ofd, event_fd, "preview task", SWICOL_TL_18, SW_SUCCESS);
+			if (ret) retval ++;
+		}
 	}
 		
 	/*
@@ -3583,7 +3591,7 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	if (opt_preview == 0 && retval == 0) {
 		/* TS_load_index_file_91 */
 		update_fileset_state(swi, "*", SW_STATE_INSTALLED);
-		ret = write_tar_installed_software_index_file(swi,
+		ret = write_tar_installed_software_index_file(G, swi,
 			vofd,
 			catalog_path,
 			pax_read_command,
@@ -3599,21 +3607,14 @@ arfinstall_tar(SWI * swi, int ofd, int efd, int do_preview,
 	 * ===================================================
 	 */
 
-/* construct_analysis_script(tmp,  swi); */
-/* JLJL */ /* swicat_write_installed_software(swi, STDERR_FILENO);  */
-/*
-*/
-strob_strcpy(tmp, "");
-/* construct_prepost_script(tmp, swi, SW_A_postinstall); */
-strob_strcpy(tmp, "");
-construct_execution_phase_script(swi, tmp,  pax_read_command);
-/* fprintf(stderr, "%s", strob_str(tmp));
-*/
+	strob_strcpy(tmp, "");
+	construct_execution_phase_script(G, swi, tmp,  pax_read_command);
 
 	strob_close(catalogdir);
 	strob_close(newnamebuf);
 	strob_close(namebuf);
 	strob_close(tmp);
+	strob_close(tmp2);
 	strob_close(tmp_swpath_ex);
 	strob_close(resolved_path);
 	strob_close(execution_phase_script);
@@ -3624,7 +3625,7 @@ construct_execution_phase_script(swi, tmp,  pax_read_command);
 
 static
 int
-write_target_install_script(
+write_target_install_script(GB * G,
 		int ofd, 
 		char * fp_targetpath, 
 		STROB * control_message, 
@@ -3690,9 +3691,9 @@ write_target_install_script(
 	 * and product tags and revisions.
 	 */
 
-	if (swlib_is_sh_tainted_string(installed_software_catalog)) { return 2; }
-	if (swlib_is_sh_tainted_string(distdata->dist_tagM)) { return 2; }
-	if (swlib_is_sh_tainted_string(distdata->catalog_bundle_dir1M)) { return 2; }
+	if (swlib_is_sh_tainted_string(installed_software_catalog)) { return 4; }
+	if (swlib_is_sh_tainted_string(distdata->dist_tagM)) { return 5; }
+	if (swlib_is_sh_tainted_string(distdata->catalog_bundle_dir1M)) { return 6; }
 	idx = 0;
 
 	/*
@@ -3716,10 +3717,10 @@ write_target_install_script(
 	while(prodtag) {
 		strob_strcpy(tmp, strob_str(catbuffer));
 		if (swlib_is_sh_tainted_string(prodtag)) { 
-			return 2;
+			return 7;
 		}
 		if (swlib_is_sh_tainted_string(prodrev)) { 
-			return 2;
+			return 8;
 		}
 		swlib_unix_dircat(tmp, prodtag);
 		strob_strcat(tmp, "/");
@@ -3730,7 +3731,7 @@ write_target_install_script(
 			 * Default revision policy is currently
 			 * return with error.
 			 */
-			return 2;
+			return 9;
 			strob_strcat(tmp, SWBIS_DEFAULT_REVISION);
 		}
 		strar_add(catalogpathlist, strob_str(tmp));
@@ -3785,7 +3786,7 @@ write_target_install_script(
 				targetpath[strlen(targetpath) - 1] == '/');
 
 	swlib_doif_writef(vlv, SWC_VERBOSE_IDB, 
-		logspec, get_stderr_fd(), 
+		logspec, swc_get_stderr_fd(G), 
 			"swc_write_target_copy_script : source_type [%s]\n",
 						 strob_str(control_message));
 	/*
@@ -4012,6 +4013,9 @@ write_target_install_script(
 	free(source_basename);
 	free(target_dirname);
 	free(target_basename);
+        if (G->g_target_script_name) {
+                swc_tee_to_file(G->g_target_script_name, strob_str(buffer));
+        }
 	strob_close(buffer);
 	strob_close(catbuffer);
 	strob_close(tmp);
@@ -4024,7 +4028,7 @@ write_target_install_script(
 	
 	if (ret <= 0) retval = 1;
 	swlib_doif_writef(vlv, SWC_VERBOSE_IDB, 
-		logspec, get_stderr_fd(), 
+		logspec, swc_get_stderr_fd(G), 
 			"swc_write_target_copy_script : retval = [%d]\n",
 				retval);
 	/*
@@ -4041,7 +4045,7 @@ write_target_install_script(
 /* ---------------------------------------------------------------- */
 
 int
-swinstall_write_target_install_script(
+swinstall_write_target_install_script(GB * G,
 		int ofd,
 		char * fp_targetpath, 
 		STROB * control_message, 
@@ -4063,6 +4067,7 @@ swinstall_write_target_install_script(
 {
 	return
 	write_target_install_script(
+		G,
 		ofd,
 		fp_targetpath, 
 		control_message, 
@@ -4083,7 +4088,7 @@ swinstall_write_target_install_script(
 }
 
 int
-swinstall_arfinstall(SWI * swi, int ofd, int efd, int do_preview, int * deadman,
+swinstall_arfinstall(GB * G, SWI * swi, int ofd, int efd, int * deadman,
 	char * target_path, char * catalog_prefix, VPLOB * swspecs,
 	int section, int altofd, int opt_preview, char * pax_read_command_key,
 	int alt_catalog_root, int event_fd, struct extendedOptions * opta,
@@ -4112,14 +4117,32 @@ swinstall_arfinstall(SWI * swi, int ofd, int efd, int do_preview, int * deadman,
 	 * target path is the absolute path
 	 */
 	
-	if (
-		swlib_check_clean_absolute_path(swi->swi_pkgM->target_pathM) ||
-		swlib_check_clean_path(swi->swi_pkgM->catalog_entryM) ||
-		0
-	) {
-		return 2;
+	E_DEBUG("HERE");
+	if (swi->swc_idM == SWC_U_L) {
+		;
+	} else {
+		if (
+			swlib_check_clean_absolute_path(swi->swi_pkgM->target_pathM) ||
+			0
+		) {
+			E_DEBUG2("HERE path is [%s]", swi->swi_pkgM->target_pathM);
+			return 10;
+		}
+	}
+	
+	E_DEBUG("HERE");
+	if (strlen(swi->swi_pkgM->catalog_entryM)) {
+		/* Disable the check for zero length strings since this is what
+		   happens when swlist uses this routine in list mode */
+		if (
+			swlib_check_clean_path(swi->swi_pkgM->catalog_entryM) ||
+			0
+		) {
+			return 3;
+		}
 	}
 
+	E_DEBUG("HERE");
 	format = xformat_get_format(xformat);
 
 	swicol_set_targetpath(swi->swicolM, target_path);
@@ -4130,17 +4153,18 @@ swinstall_arfinstall(SWI * swi, int ofd, int efd, int do_preview, int * deadman,
 		*/
 		/*
 		STROB * tmp = strob_open(10);
-		swextopt_write_session_options(tmp, opta, SWC_I);
+		swextopt_write_session_options(tmp, opta, SWC_U_I);
 		fprintf(stderr, "%s", strob_str(tmp));
 		strob_close(tmp);
 		*/
 	} /* -+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+ */ 
 
+	E_DEBUG("HERE");
 	if (format == arf_tar || format == arf_ustar) {
 		/*
 		 * All tar formats
 		 */
-		ret = arfinstall_tar(swi, ofd, efd, do_preview, deadman,
+		ret = arfinstall_tar(G, swi, ofd, efd, deadman,
 				target_path, catalog_prefix, swspecs,
 				section, altofd, opt_preview, pax_read_command_key,
 				alt_catalog_root, event_fd, opta, logspec, keep_old_files, pstatbytes);
