@@ -1,6 +1,4 @@
-/* $Id: swexstruct_i.h,v 1.1 1999/12/27 14:48:15 jhl Exp jhl $
- * 	The Exported Package Structure Base Class Implementation.
- *
+/* swexstruct_i.h: The Exported Package Structure Base Class Implementation.
  */
 
 /*
@@ -657,13 +655,13 @@ class swExStruct_i: public swExStruct
 	}
 	
 	void
-	set_md5_creation(int s) {
+	set_digests1_creation(int s) {
 		if (s) {
 			 // On
-			 cksumflagsM |= SWFILE_DO_MD5SUM;
+			 cksumflagsM |= SWFILE_DO_FILE_DIGESTS;
 		} else {
 			// Off
-			cksumflagsM &= ~(SWFILE_DO_MD5SUM);
+			cksumflagsM &= ~(SWFILE_DO_FILE_DIGESTS);
 		}
 	}
 
