@@ -1,6 +1,4 @@
-/* $Id: swobjfiles_i.h,v 1.1 1999/12/27 14:49:14 jhl Exp jhl $
- * swobjfiles_i.h - The common (dfile/pfiles/fileset) exported file structure.
- *
+/* swobjfiles_i.h - The common (dfile/pfiles/fileset) exported file structure.
  */
 
 /*
@@ -241,7 +239,10 @@ class swObjFiles_i:  public swExStruct_i
 	
 		x = cwdmode & (S_IRWXU | S_IRWXG | S_IRWXO |
 					S_ISUID | S_ISGID | S_ISVTX);
-		finalperms = 0750;
+		//
+		// This determines the permission mode of the control
+		// directories.
+		finalperms = 0755;
 		if (x != 0) {
 			finalperms = x;
 			if (cwdmode & S_ISUID) finalperms |= S_ISUID;
@@ -267,7 +268,12 @@ class swObjFiles_i:  public swExStruct_i
 	
 		x = cwdmode & (S_IRWXU | S_IRWXG | S_IRWXO | 
 					S_ISUID | S_ISGID | S_ISVTX);
-		finalperms = 0640;
+		//
+		// this determines the permissions of internally generated 
+		// control_files such as INFO
+		//
+		finalperms = 0644;
+
 		if (x != 0) {
 			finalperms = x;
 			finalperms &= ~(S_IXOTH | S_IXGRP | S_IXUSR);
@@ -621,13 +627,14 @@ class swObjFiles_i:  public swExStruct_i
 		swMetaData * att;
 		swINFO * info = getInfo();
 		swDefinition * xcfile;	
+		STROB * tmp;
 
 		if (info == NULL) {
 			return;
 		} else {
 			;
 		}
-		
+
 		inext = info->swdeffile_linki_get_head();
 
 		while(inext) {
@@ -654,7 +661,7 @@ class swObjFiles_i:  public swExStruct_i
 		// Make a control_file definition.
 		//
 		xcfile = swDefinition::make_newDefinition(getReferer(), SW_A_control_file);
-		xcfile->set_level(4);
+		xcfile->set_level(3);
 		xcfile->set_no_stat(1);
 		xcfile->add(SW_A_source, "INFO");
 		att = xcfile->findAttribute(SW_A_source);
@@ -666,6 +673,11 @@ class swObjFiles_i:  public swExStruct_i
 		xcfile->add(SW_A_path, "INFO");
 		xcfile->add(SW_A_tag, "INFO");
 		xcfile->add(SW_A_size, INFO_SIZE_BLANK);
+		tmp = strob_open(10);
+		strob_sprintf(tmp, 0, "%lu", getCreateTime());
+		xcfile->add(SW_A_mtime, strob_str(tmp));
+		xcfile->add(SW_A_mode, getCatalogFileModeString());
+		strob_close(tmp);
 		info->swdeffile_linki_preppend(xcfile);	
 		return;
 	}
@@ -703,7 +715,7 @@ class swObjFiles_i:  public swExStruct_i
 		while(inext) {
 			tagvalue = inext->find(SW_A_tag);
 			if (::strcmp(tagvalue, "INFO") == 0) {
-				value = inext->find("size");
+				value = inext->find(SW_A_size);
 				if (value == NULL) {
 					setErrorCode(10302, NULL);
 					return;
@@ -1062,11 +1074,11 @@ class swObjFiles_i:  public swExStruct_i
 	}
 
 	void registerAttributeFiles(void) {
-		char asize[30];
 		int nullfd;
 		int fd;
 		int index;
 		int size;
+		mode_t filemode;
 		swMetaData * att;
 		swMetaData * attReferer;
 		swPackageFile * swfile;
@@ -1133,7 +1145,6 @@ class swObjFiles_i:  public swExStruct_i
 			//
 			xcfile = swDefinition::make_newDefinition(getReferer(), SW_A_control_file);
 
-			//strob_strcpy(tmp, SWBIS_NO_STAT_INDICATOR);
 			strob_strcpy(tmp, "");
 			strob_strcat(tmp, swfile->swfile_get_source_filename());
 
@@ -1175,11 +1186,23 @@ class swObjFiles_i:  public swExStruct_i
 			}
 			xcfile->add(SW_A_tag, strob_str(tmp));
 
-			snprintf(asize, sizeof(asize) -1, "%8d", size);
-			asize[sizeof(asize) - 1] = '\0';
-			xcfile->add("size", asize);
+			// Add the size attribute
+			strob_sprintf(tmp, 0, "%8d", size);
+			xcfile->add(SW_A_size, strob_str(tmp));
+
+			// Add the mtime attribute 
+			strob_sprintf(tmp, 0, "%lu", (unsigned long)(swfile->xFormat_get_mtime()));
+			xcfile->add(SW_A_mtime, strob_str(tmp));
+
+			// Add the mode attribute 
+			filemode = swfile->xFormat_get_mode();
+			filemode &= ~(S_ISGID | S_ISUID);
+			filemode &= (0777);
+			strob_sprintf(tmp, 0, "%o", (unsigned int)(filemode));
+			xcfile->add(SW_A_mode, strob_str(tmp));
+
 			info->swdeffile_linki_append(xcfile);	
-			
+	
 			swfile = archiveMemberList->get_pointer_from_index(
 								index++);
 		}
@@ -1277,8 +1300,7 @@ class swObjFiles_i:  public swExStruct_i
 		info->swfile_set_package_filename(strob_str(tmp));
 
 		filemode = info->xFormat_get_mode();
-		filemode &= ~(S_ISGID | S_ISUID | S_IXOTH |
-						S_IXGRP | S_IXUSR);
+		// filemode &= ~(S_ISGID | S_ISUID | S_IXOTH | S_IXGRP | S_IXUSR);
 		info->xFormat_set_mode(filemode);
 		swexstruct_write_definitionfile(info,
 				getCreateTime(),
@@ -1327,7 +1349,7 @@ class swObjFiles_i:  public swExStruct_i
 				strar_add(pathlist, strob_str(tmp));
 			}
 
-			swfile->xFormat_set_perms(0755);
+			// swfile->xFormat_set_perms(0755);
 			swfile->xFormat_set_user_systempair(getCatalogOwner());
 			swfile->xFormat_set_group_systempair(getCatalogGroup());
 			ret = 0;
@@ -1621,8 +1643,7 @@ class swObjFiles_i:  public swExStruct_i
 		if (swfile->getArchiveInclude()) {
 			int ret;
 			filemode = swfile->xFormat_get_mode();
-			filemode &= ~(S_ISGID | S_ISUID | S_IXOTH |
-						S_IXGRP | S_IXUSR);
+			// filemode &= ~(S_ISGID | S_ISUID | S_IXOTH | S_IXGRP | S_IXUSR);
 			swfile->xFormat_set_mode(filemode);
 			swfile->xFormat_set_user_systempair(getCatalogOwner());
 			swfile->xFormat_set_group_systempair(getCatalogGroup());
@@ -1748,7 +1769,14 @@ class swObjFiles_i:  public swExStruct_i
 			// Apply the create_time to this file.
 			//
 			swattfile->xFormat_set_mode(0);
-			swattfile->xFormat_set_perms(0640);
+
+			//
+			// the next line determines the permissions of internally
+			// generated attribute files such as md5sum, sha1sum,
+			// and sig_header, and signature
+			//
+			swattfile->xFormat_set_perms(0644);
+
 			swattfile->xFormat_set_mtime(getCreateTime());
 			swattfile->xFormat_set_filetype_from_tartype(REGTYPE);
 		}
@@ -1758,13 +1786,13 @@ class swObjFiles_i:  public swExStruct_i
 		// (i.e. override the &st buffer that was just set into
 		// the swatfile).
 		//
+
 		if (swdef) {
 			if (swattfile->xFormat_apply_swdef_stats(swdef,
 						source, logical_find, (STROB*)(NULL))) {
 				setErrorCode(10449, NULL);
 			}
 		}
-
 				// Hack, Release the fd, but keep the data. 
 		swattfile->swfile_re_close_public_image_fd();
 		
