@@ -1,6 +1,4 @@
-/* $Id: swdefcontrolfile.cxx_v 1.2 1998/10/24 23:40:16 jhl Exp jhl $
- * swdefcontrolfile.cxx
- *
+/* swdefcontrolfile.cxx
  */
 
 /*
@@ -66,13 +64,14 @@ void swDefControlFile::apply_file_stat_specialization(char fileArray[][file_perm
 	swMetaData * swmd;
 
 	fileArrayWasSet[ctimeE] = 0;
-	fileArrayWasSet[mtimeE] = 0;
+	// fileArrayWasSet[mtimeE] = 0;
 	fileArrayWasSet[umaskE] = 0;
+	fileArrayWasSet[sha1sumE] = 0;
 	fileArrayWasSet[md5sumE] = 0;
 	fileArrayWasSet[cksumE] = 0;
 	fileArrayWasSet[gidE] = 0;
 	fileArrayWasSet[uidE] = 0;
-	fileArrayWasSet[modeE] = 0;
+	// fileArrayWasSet[modeE] = 0;
 
 	for (i=0; i<lastE; i++) {
 		if (fileArrayWasSet[i] == 0) {
