@@ -1,4 +1,4 @@
-/* $Id: swdefinitionfile.h,v 2.6 2000/03/19 03:01:12 jhl Exp jhl $
+/* swdefinitionfile.h
  *
  */
 
@@ -181,7 +181,7 @@ public:
 	
 	static char * swdeffile_linki_nextline(void * the_this_object, int * current_offset, int peek);
 	//static int swdeffile_linki_write_fd(swDefinitionFile * swdef, int ofd);
-	int swdeffile_linki_write_fd(int ofd);
+	virtual int swdeffile_linki_write_fd(int ofd);
 	int swdeffile_linki_write_fd_debug(int ofd, char * prefix);
 	swDefinition * find_same_prior_file(swDefinition * newswdef, int start_index);
 	
