@@ -1,6 +1,4 @@
-/* $Id$
- * swextendeddef.h  -- Process PSF Extended Definitions.
- *			
+/* swextendeddef.h  -- Process PSF Extended Definitions.
  */
 
 /*
@@ -26,11 +24,13 @@
 #ifndef swextdef_20041023_h
 #define swextdef_20041023_h
 
+
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
 #include <assert.h>
 #include <unistd.h>
+#include "swuser_config.h"
 #include "swmetadata.h"
 #include "swattributemem.h"
 #include "swstructdef.h"
@@ -38,16 +38,16 @@
 #include "swdefinitionfile.h"
 #include "swpsfi.h"
 extern "C" {
-#include "swuser_config.h"
+#include "misc-fnmatch.h"
 #include "swlib.h"
 #include "uxfio.h"
 #include "strob.h"
+#include "strar.h"
 #include "swvarfs.h"
 #include "swheaderline.h"
 #include "taru.h"
 }
 
-
 #ifdef SWEXTDEFNEEDDEBUG
 #define SWEXTDEF_DEBUG(format) SWBISERROR("SWEXTDEF DEBUG: ", format)
 #define SWEXTDEF_DEBUG2(format, arg) SWBISERROR2("SWEXTDEF DEBUG: ", format, arg)
@@ -58,7 +58,6 @@ extern "C" {
 #define SWEXTDEF_DEBUG3(arg, arg1, arg2)
 #endif 
 
-
 class swExtendedDef : private swMetaData
 {
 
@@ -164,7 +163,7 @@ public: // =====================================================================
 	// Public
 	//
 	void
-	set_md5_creation(int s)
+	set_digests1_creation(int s)
 	{
 		SWEXTDEF_DEBUG("ENTER");
 		do_create_md5sumM = s;
@@ -595,7 +594,103 @@ public: // =====================================================================
 	//
 	int
 	processExcludes(swDefinitionFile* psf, char * value) {
-		STROB * psrc = strob_open(24);
+		int i;
+		STROB * excl_pat;
+		STRAR * pat_list;
+		swDefinition * swdef;
+		char * source;
+		char * isource;
+		char * def_source;
+		char * mdef_source;
+		int is_dir;
+		int t_dflag;
+		int l_dflag;
+		int first_match;
+		char * type;
+
+		is_dir = 0;
+		t_dflag = 0;
+		l_dflag = 0;
+		i = excl_sindexM;
+		first_match = 0;
+		excl_pat = strob_open(100);
+		pat_list = strar_open();
+	
+		parse_SourcePath(value, &source, &isource);
+
+		strob_strcpy(excl_pat, strob_str(directory_sourceM));
+		swlib_unix_dircat(excl_pat, source);
+		swlib_toggle_trailing_slashdot("drop", strob_str(excl_pat), &t_dflag);
+		swlib_toggle_leading_dotslash("drop", strob_str(excl_pat), &l_dflag);
+
+		while ((swdef=psf->swdeffile_get_pointer_from_index(i++)) != static_cast<swDefinition*>(NULL)) {
+			if(strcmp("file", swdef->get_keyword())) {
+				//
+				// Sanity check
+				// 
+				fprintf(stderr,"swpackage: Error: Non file object found in list in processExcludes().\n");
+				return -1;
+			}		
+			def_source = swdef->find(SW_A_source);
+			if (def_source == static_cast<char *>(NULL)) {
+				//
+				// Sanity check
+				// 
+				fprintf(stderr,"swpackage: error: path attribute not found in processExcludes().\n");
+				return -1;
+			}
+
+			//
+			// Strip off absolute part if directory_sourceM is relative.
+			//
+			if (*strob_str(directory_sourceM) != '/' && excl_qindexM > 0) {
+				mdef_source = def_source + ((excl_qindexM > (int)strlen(def_source)) ? strlen(def_source) : excl_qindexM);
+			} else {
+				mdef_source = def_source;
+			}
+
+			SWEXTDEF_DEBUG3("comparing for exclusion : fnmatch [%s] [%s]", strob_str(excl_pat), mdef_source);
+			strar_add(pat_list, strob_str(excl_pat));
+			// if (fnmatch(strob_str(excl_pat), mdef_source, 0) == 0) {
+			if (process_fnmatch_list(pat_list, mdef_source) == 0) {
+				//
+				// Got match
+				//
+				SWEXTDEF_DEBUG3("fnmatch result: GOT MATCH [%s] [%s]", strob_str(excl_pat), mdef_source);
+				type = swdef->find(SW_A_type);
+				if (type == static_cast<char *>(NULL)) {
+					//
+					// Sanity check
+					// 
+					fprintf(stderr,"swpackage: error: type attribute not found in processExcludes().\n");
+					return -1;
+				}
+				if (first_match == 0 && *type == 'd') {
+					strob_strcat(excl_pat, "/*");
+					strar_add(pat_list, strob_str(excl_pat));
+				}
+				if (first_match == 0)
+					first_match = 1;
+				psf->swdeffile_list_del(--i);
+			} else {
+				;
+				SWEXTDEF_DEBUG3("fnmatch result: NO MATCH [%s] [%s]", strob_str(excl_pat), mdef_source);
+			}
+		}
+		strob_close(excl_pat);
+		strar_close(pat_list);
+		// swlib_toggle_trailing_slashdot("restore", source, &t_dflag);
+		// swlib_toggle_leading_dotslash("restore", source, &l_dflag);
+		return 0;
+	}
+
+	// Public
+	//
+	// 5.2.13.5 Exclude Files
+	//
+	int
+	processExcludesOld(swDefinitionFile* psf, char * value) {
+		STROB * psrc;
 		struct stat st;
 		int i = excl_sindexM;
 		swDefinition * swdef;
@@ -607,6 +702,7 @@ public: // =====================================================================
 		int l_dflag = 0;
 
 		SWEXTDEF_DEBUG2("ENTER %s", value);
+		psrc = strob_open(24);
 		parse_SourcePath(value, &source, &isource);	// isource is a dummy variable in this usage.
 
 		//
@@ -640,8 +736,11 @@ public: // =====================================================================
 		while ((swdef=psf->swdeffile_get_pointer_from_index(i++)) != static_cast<swDefinition*>(NULL)) {
 			SWEXTDEF_DEBUG2("keyword is %s", swdef->get_keyword());
 			if(strcmp("file", swdef->get_keyword())) {
+				//
+				// Sanity check
 				// This really is an error, not a warning.
 				fprintf(stderr,"swpackage: Error: Non file object found in list in processExcludes().\n");
+				strob_close(psrc);
 				return -1;
 			}		
 			isource = swdef->find(SW_A_source);
@@ -650,6 +749,7 @@ public: // =====================================================================
 				strob_close(psrc);
 				return -1;
 			}
+
 			//
 			// Strip off absolute part if directory_sourceM is relative.
 			//
@@ -666,14 +766,14 @@ public: // =====================================================================
 			if (compare_exclude(misource, source, is_dir) == 0) {
 				// Do exclude.
 				psf->swdeffile_list_del(--i);		
-				//fprintf(stderr,"Excluding misource=%s source=%s\n", misource, source );
-				if (!is_dir) {
+				SWEXTDEF_DEBUG3("compared for exclusion : result=EXCLUDED [%s] [%s]", misource, source);
+				if (!is_dir && pattern_is_wild(source) == 0) {
 					// Only match one time.
 					break;
 				}
 			} else {
 				;
-				//fprintf(stderr,"Keeping misource=%s source=%s\n", misource, source);
+				SWEXTDEF_DEBUG3("compared for exclusion : result=RETAINED [%s] [%s]", misource, source);
 			}
 		}
 
@@ -775,6 +875,29 @@ private: // ================================================================
 	 // ================================================================
 	 // ================================================================
 
+	int
+	process_fnmatch_list(STRAR * pat_list, char * mdef_source) {
+		int i;
+		char * pat;
+		int ret;
+
+		ret = 1;
+		i = 0;
+		pat = strar_get(pat_list, i++);
+		while(pat && ret) {
+			ret = fnmatch(pat, mdef_source, 0);
+			if (ret == 0) break;
+			pat = strar_get(pat_list, i++);
+		}	
+		return ret;
+	}
+
+	int
+	pattern_is_wild(char * p) {
+		if (strpbrk(p, "?*[")) return 1;
+		else return 0;
+	}
+
 	void
 	recursive_list_unique_add(swDefinitionFile * psf, swDefinition * swdef) {
 		//
@@ -896,6 +1019,7 @@ private: // ================================================================
 				case compE:
 				case cksumE:
 				case md5sumE:
+				case sha1sumE:
 				case mtimeE:
 				case ctimeE:
 				case inoE:
@@ -1217,9 +1341,10 @@ private: // ================================================================
 		if (!strncmp(s, "./", 2)) return s+2;
 		return s;
 	}
+
 	
 	int
-	compare_exclude(char * fp_attr_source, char * fp_xsource, int is_dir) {
+	compare_exclude_no_wild(char * fp_attr_source, char * fp_xsource, int is_dir) {
 		char * s, *end;
 		char * attr_source;
 		char * xsource;
@@ -1304,6 +1429,24 @@ private: // ================================================================
 		}
 	}
 	
+	int
+	compare_exclude(char * fp_attr_source, char * fp_xsource, int is_dir) {
+		int ret;	
+		SWEXTDEF_DEBUG("entering");
+		if (pattern_is_wild(fp_xsource)) {
+			ret = fnmatch(fp_xsource, fp_attr_source, 0);
+			if (ret == 0) {
+				ret = compare_exclude_no_wild(fp_attr_source, fp_attr_source, 1);
+			}
+			SWEXTDEF_DEBUG2("fnmatch returned %d", ret);
+		} else {		
+			ret = compare_exclude_no_wild(fp_attr_source, fp_xsource, is_dir);
+			SWEXTDEF_DEBUG2("compare_exclude_no_wild returned %d", ret);
+		}
+		SWEXTDEF_DEBUG2("leaving with return value=%d", ret);
+		return ret;
+	}
+	
 	void
 	set_start_index(swDefinitionFile * psf, swDefinition * swdef) {
 		if (!excl_sindexM) {
@@ -2071,7 +2214,7 @@ private: // ================================================================
 				cksumflags |= SWFILE_DO_CKSUM;
 			}
 			if (do_create_md5sumM) {
-				cksumflags |= SWFILE_DO_MD5SUM;
+				cksumflags |= SWFILE_DO_FILE_DIGESTS;
 			}
 	
 			init_statArray();
@@ -2094,6 +2237,7 @@ private: // ================================================================
 			if (do_create_md5sumM) {
 				copy_file_cell(fileArrayM, fileArrayWasSetM, md5sumE, statArrayM[md5sumE]);
 			}
+			copy_file_cell(fileArrayM, fileArrayWasSetM, sha1sumE, statArrayM[sha1sumE]);
 		}
 		return 0;
 	}
@@ -2430,6 +2574,7 @@ private: // ================================================================
 				case compE:
 				case cksumE:
 				case md5sumE:
+				case sha1sumE:
 				case mtimeE:
 				case ctimeE:
 				case inoE:
