@@ -1,4 +1,4 @@
-// $Id: swmetadata_i.cxx,v 1.3 2000/03/13 05:15:54 jhl Exp jhl $
+//  swmetadata.cxx
 //
 //  Copyright (C) 1998-2004 James H. Lowe, Jr. <jhlowe@acm.org>
 //  All Rights Reserved.
@@ -28,7 +28,7 @@ swstructdef * swMetaData::defaults_;
 char * swMetaData::namesM[] = {"type", "mode", "mtime", "ctime", "owner", 
 				"uid", "group", "gid", "umask", "size", 
 				"is_volatile", "compression_state", "cksum", 
-				"md5sum", "link_source", "minor", "major",
+				"md5sum", "sha1sum", "link_source", "minor", "major",
 				"_ino", "_nlink", "_complete", ""};
 
 
@@ -419,7 +419,8 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 		mode_t mode;
 		int intval;
 		int u_fd = -1;
-		int do_create_cksum, do_create_md5sum;
+		int do_create_cksum;
+		int do_create_file_digests;
 		int ret = 0;
 		int devnum;
 		HLLIST * hllist = swvarfs_get_hllist(swvarfs);
@@ -429,7 +430,7 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 
 		SWMETADATA_DEBUG("");
 		do_create_cksum = cksumflags & SWFILE_DO_CKSUM;
-		do_create_md5sum = cksumflags & SWFILE_DO_MD5SUM;
+		do_create_file_digests = cksumflags & SWFILE_DO_FILE_DIGESTS;
 		
 		//
 		// File Type
@@ -457,7 +458,7 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 		array_is_set[typeE] = 1;
 		array_is_set[cksumE] = 0;
 
-		if ((do_create_cksum || do_create_md5sum) && *p_type == SW_ITYPE_f ) {
+		if ((do_create_cksum || do_create_file_digests) && *p_type == SW_ITYPE_f ) {
 			unsigned long ck;
 			u_fd = swMetaData::swmetadata_local_open(swvarfs, source);
 			if (u_fd < 0) {
@@ -465,7 +466,10 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 				return -1;
 			} else {
 				char bufc[60];
+				char bufc_sha1[60];
 				bufc[0] = '\0';
+				bufc_sha1[0] = '\0';
+
 				if (do_create_cksum) {
 					uxfio_lseek(u_fd, 0, SEEK_SET);
 					ck = ::swlib_cksum(u_fd);
@@ -474,7 +478,7 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 					::swlib_strncpy(array[cksumE], bufc, file_permsLength - 1);
 					array_is_set[cksumE] = 1;
 				}
-				if (do_create_md5sum) {
+				if (do_create_file_digests) {
 					if (bufc[0] != '\0') {  // Optimization.
 						//
 						// Need to rewind the file.
@@ -485,9 +489,17 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 							exit(52);
 						}
 					}
-					swlib_md5(u_fd, (unsigned char *)bufc, 1);
+					// swlib_md5(u_fd, (unsigned char *)bufc, 1);
+					if (swlib_digests(u_fd, bufc, bufc_sha1)) {
+						// Fatal error
+						fprintf(stderr, 
+						"Internal software error in swlib_digests\n");
+						exit(52);
+					}
 					::swlib_strncpy(array[md5sumE], bufc, file_permsLength - 1);
 					array_is_set[md5sumE] = 1;
+					::swlib_strncpy(array[sha1sumE], bufc_sha1, file_permsLength - 1);
+					array_is_set[sha1sumE] = 1;
 				}
 				swMetaData::swmetadata_local_close(swvarfs, u_fd);
 			}
@@ -571,18 +583,22 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 		if (*p_type == SW_ITYPE_f) {
 			SWMETADATA_DEBUG("");
 			snprintf(p_size, file_permsLength,  "%d", (int)(st->st_size));
+			p_size[file_permsLength-1] = '\0';
 			array_is_set[sizeE] = 1;
 		} else if (*p_type == SW_ITYPE_s) {
 			SWMETADATA_DEBUG("");
 			snprintf(p_size, file_permsLength, "%d", (int)(strlen( p_linksource)));
+			p_size[file_permsLength-1] = '\0';
 			array_is_set[sizeE] = 1;
 		} else if (*p_type == SW_ITYPE_h) {
 			SWMETADATA_DEBUG("");
 			snprintf(p_size, file_permsLength, "%d", (int)(0));
+			p_size[file_permsLength-1] = '\0';
 			array_is_set[sizeE] = 1;
 		} else {
 			SWMETADATA_DEBUG("");
 			snprintf(p_size, file_permsLength, "%d", (int)(0));
+			p_size[file_permsLength-1] = '\0';
 			array_is_set[sizeE] = 1;
 		}
 
@@ -594,6 +610,7 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 			mode = st->st_mode;	
 			mode &= (S_IRWXU|S_IRWXG|S_IRWXO|S_ISUID|S_ISGID|S_ISVTX);
 			snprintf(p_mode, file_permsLength, "%o", (unsigned int)mode);
+			p_mode[file_permsLength-1] = '\0';
 			array_is_set[modeE] = 1;
 		} else {
 			;
@@ -607,6 +624,7 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 			SWMETADATA_DEBUG("p_ctime == nil");
 			filetime = (unsigned long)(st->st_ctime);
 			snprintf(p_ctime, file_permsLength, "%lu", filetime);
+			p_ctime[file_permsLength-1] = '\0';
 			array_is_set[ctimeE] = 0;  // Don't include ctime.
 		} else {
 			;
@@ -619,6 +637,7 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 			SWMETADATA_DEBUG("p_mtime == nil");
 			filetime = (unsigned long)(st->st_mtime);
 			snprintf(p_mtime, file_permsLength, "%lu", filetime);
+			p_mtime[file_permsLength-1] = '\0';
 			array_is_set[mtimeE] = 1;
 		} else {
 			;
@@ -632,6 +651,7 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 			SWMETADATA_DEBUG("p_ino == nil");
 			filetime = (unsigned long)(st->st_ino);
 			snprintf(p_ino, file_permsLength, "%lu", filetime);
+			p_ino[file_permsLength-1] = '\0';
 			SWMETADATA_DEBUG2("p_ino set: [%s]", p_ino);
 			array_is_set[inoE] = 1;
 		} else {
@@ -646,6 +666,7 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 			SWMETADATA_DEBUG("p_nlink == nil");
 			intval = (int)(st->st_nlink);
 			snprintf(p_nlink, file_permsLength, "%d", intval);
+			p_nlink[file_permsLength-1] = '\0';
 			array_is_set[nlinkE] = 1;
 			SWMETADATA_DEBUG2("p_nlink set: [%s]", p_nlink);
 		} else {
@@ -660,6 +681,7 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 			SWMETADATA_DEBUG("p_major == nil");
 			devnum = major(st->st_rdev);
 			snprintf(p_major, file_permsLength, "%d", devnum);
+			p_major[file_permsLength-1] = '\0';
 			array_is_set[majorE] = 1;
 			SWMETADATA_DEBUG2("p_major set: [%s]", p_major);
 		} else {
@@ -674,6 +696,7 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 			SWMETADATA_DEBUG("p_minor == nil");
 			devnum = minor(st->st_rdev);
 			snprintf(p_minor, file_permsLength, "%d", devnum);
+			p_minor[file_permsLength-1] = '\0';
 			array_is_set[minorE] = 1;
 			SWMETADATA_DEBUG2("p_minor now set: [%s]", p_minor);
 		} else {
@@ -689,6 +712,7 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 			SWMETADATA_DEBUG("p_owner == nil");
 			taru_get_user_by_uid(uid,  p_owner);
 			snprintf(p_uid,  file_permsLength, "%d",(int)uid);
+			p_uid[file_permsLength-1] = '\0';
 			array_is_set[ownerE] = 1;
 			array_is_set[uidE] = 1;
 			SWMETADATA_DEBUG2("p_owner set: [%s]", p_owner);
@@ -696,6 +720,7 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 			uid_t uid = st->st_uid;
 			SWMETADATA_DEBUG2("p_owner Doing numeric: [%s]", p_owner);
 			snprintf(p_uid,  file_permsLength, "%d",(int)uid);
+			p_uid[file_permsLength-1] = '\0';
 			*p_owner == '\0';
 			array_is_set[ownerE] = 0;
 			array_is_set[uidE] = 1;
@@ -712,6 +737,7 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 			SWMETADATA_DEBUG("p_group == nil");
 			taru_get_group_by_gid(gid, p_group);
 			snprintf(p_gid,  file_permsLength, "%d",(int)gid);
+			p_gid[file_permsLength-1] = '\0';
 			array_is_set[groupE] = 1;
 			array_is_set[gidE] = 1;
 			SWMETADATA_DEBUG2("p_group set: [%s]", p_group);
@@ -719,6 +745,7 @@ int swMetaData::swmetadata_decode_file_stats(SWVARFS * swvarfs,
 			gid_t gid = st->st_gid;
 			SWMETADATA_DEBUG2("p_group Doing numeric: [%s]", p_group);
 			snprintf(p_gid,  file_permsLength, "%d",(int)gid);
+			p_gid[file_permsLength-1] = '\0';
 			*p_group == '\0';
 			array_is_set[groupE] = 0;
 			array_is_set[gidE] = 1;
