@@ -1,6 +1,4 @@
-/* $Id: swpackagefile.cxx,v 1.8 2000/04/06 22:39:41 jhl Exp jhl $
- * swpackagefile.cxx -
- *
+/* swpackagefile.cxx
  */ 
 
 /*
@@ -111,6 +109,7 @@ int swPackageFile::initialize_file_stats_array(swDefinition * swdef,
 			case linksourceE:
 			case cksumE:
 			case md5sumE:
+			case sha1sumE:
 			case typeE:
 			case ctimeE:
 			case mtimeE:
@@ -209,6 +208,7 @@ int swPackageFile::apply_file_stats(swDefinition * swdef, SWVARFS * swvarfs, cha
 				case compE:
 				case cksumE:
 				case md5sumE:
+				case sha1sumE:
 					SWPACKAGEFILE_DEBUG("");
 					swdef->list_replace(swmd);
 					break;
