@@ -1,5 +1,4 @@
-/* $Id: swpackagefile.h,v 1.10 2000/09/22 02:30:00 jhl Exp jhl $
- * swpackagefile.h
+/* swpackagefile.h
  */
 
 /*
@@ -172,7 +171,7 @@ class swPackageFile :  public swAttribute
     	int apply_file_stats(swDefinition * swdef, SWVARFS * swvarfs,
 					char *source, int cksumflags);
 
-	int swPackageFile::initialize_file_stats_array(swDefinition * swdef,
+	int initialize_file_stats_array(swDefinition * swdef,
 				char array[][file_permsLength],
 					int array_is_set[]); 
 
@@ -713,13 +712,6 @@ class swPackageFile :  public swAttribute
 		source = swdef->find("source");
 		no_stat = swdef->get_no_stat();
 
-/*
-fprintf(stderr, "JL ====================================================\n");
-fprintf(stderr, "JL path=%s\n", path);
-swdef->write_fd(2);
-fprintf(stderr, "JL no_stat = %d ========================================\n", no_stat);
-*/
-
 		if (!source) {
 			fprintf(stderr, "source attribute is missing\n");
 			return -3;
@@ -1126,7 +1118,7 @@ fprintf(stderr, "JL no_stat = %d ========================================\n", no
 		// apply the file stats in the definition.
 		//
 			
-		if ((value=swdef->find("mtime"))) {
+		if ((value=swdef->find(SW_A_mtime))) {
 			taru_datoul(value, &timeval);
 			xFormat_set_mtime((time_t)timeval);
 		}
@@ -1138,7 +1130,7 @@ fprintf(stderr, "JL no_stat = %d ========================================\n", no
 		//
 		// Set the user and uid
 		//
-		value2 = swdef->find("uid");
+		value2 = swdef->find(SW_A_uid);
 		set_find_mode_logical(0);
 		if ((value=swdef->find("owner"))) {
 			//
@@ -1191,9 +1183,9 @@ fprintf(stderr, "JL no_stat = %d ========================================\n", no
 		//
 		// Set the group and gid
 		//
-		value2 = swdef->find("gid");
+		value2 = swdef->find(SW_A_gid);
 		set_find_mode_logical(0);
-		if ((value=swdef->find("group"))) {
+		if ((value=swdef->find(SW_A_group))) {
 			//
 			// Got a group name
 			//
@@ -1242,16 +1234,25 @@ fprintf(stderr, "JL no_stat = %d ========================================\n", no
 		}
 		set_find_mode_logical(logical_find);
 
-		if ((value=swdef->find("mode"))) {
+		//
+		// Ignore the distribution.mode value since it is not wanted
+		// to affect file permissions in the catalog.
+		//
+		if (
+			((value=swdef->find(SW_A_mode)) != NULL) &&
+			(strcmp(swdef->get_keyword(), SW_A_distribution) != 0)
+		) {
+			// fprintf(stderr, "JL, found mode value=[%s]\n", value);
 			taru_otoul(value, &devnum);
 			xFormat_set_mode(0);
 			xFormat_set_perms((mode_t)devnum);
 		}
 		else {
+			;
 			//fprintf(stderr, "mode missing for file %s\n", source);
 		}
 		
-		if ((value=swdef->find("minor"))) {
+		if ((value=swdef->find(SW_A_minor))) {
 			taru_datoul(value, &devnum);
 			xFormat_set_devminor((dev_t)devnum);
 		}
@@ -1259,7 +1260,7 @@ fprintf(stderr, "JL no_stat = %d ========================================\n", no
 			//fprintf(stderr, "mode missing for file %s\n", source);
 		}
 		
-		if ((value=swdef->find("major"))) {
+		if ((value=swdef->find(SW_A_major))) {
 			taru_datoul(value, &devnum);
 			xFormat_set_devmajor((dev_t)devnum);
 		}
@@ -1320,7 +1321,7 @@ fprintf(stderr, "JL no_stat = %d ========================================\n", no
 			}
 	
 			if (*type == 'b' || *type == 'c' ) {
-				if ((value=swdef->find("minor"))) {
+				if ((value=swdef->find(SW_A_minor))) {
 					sscanf(value, "%lu", &dev);
 					xFormat_set_devminor((dev_t)dev);
 				} else {
@@ -1328,7 +1329,7 @@ fprintf(stderr, "JL no_stat = %d ========================================\n", no
 					fprintf(stderr, "minor device number missing for file %s\n", source);
 				}
 	
-				if ((value=swdef->find("major"))) {
+				if ((value=swdef->find(SW_A_major))) {
 					sscanf(value, "%lu", &dev);
 					xFormat_set_devmajor((dev_t)dev);
 				} else {
