@@ -1,5 +1,4 @@
-/* $Id: rpmfd.c,v 1.1 1999/11/14 17:38:48 jhl Exp jhl $
-   rpmfd.c --
+/* rpmfd.c --
 
    Copyright (C) 1999  Jim Lowe  <jhlowe@acm.org>
    All rights reserved.
