@@ -1,5 +1,4 @@
-/* $Id$
-   shcmd.c  --  Shell-less Command pipeline object.
+/* shcmd.c  --  Shell-less Command pipeline object.
 */
 
 /*
@@ -22,6 +21,9 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
  */
 
+#define FILENEEDDEBUG 1 /* controls the E_DEBUG macros */
+#undef FILENEEDDEBUG
+
 #include <ctype.h>
 #include <sys/types.h>
 #include <pwd.h>
@@ -34,6 +36,9 @@
 #include "swutilname.h"
 #include "swlib.h"
 
+
+#define SHC_DIR_DOWN 0
+#define SHC_DIR_UP 1
 #define CLOSE_LIST_LEN ((int)(sizeof(shcmd->close_list_) / sizeof(int)))
 
 int	swlib_pipe_pump(int ofd, int suction_fd);
@@ -162,7 +167,7 @@ internal_redirect(
 	if (errfd != STDERR_FILENO || errfile) {
 		if (errfd == STDERR_FILENO && !errfile) {
 			;
-		} else if (errfd > STDERR_FILENO && !errfile) {
+		} else if ((errfd > STDERR_FILENO && !errfile) || errfd == STDOUT_FILENO) {
 			if (dup2(errfd, STDERR_FILENO) != STDERR_FILENO) {
 				fprintf (stderr,"err dup error\n");
 			}
@@ -222,6 +227,9 @@ shcmd_common_open(char * cmdstring)
 	shcmd->append2_ = 0;
 	shcmd->async_ = 0;
 	shcmd->close_all_fd_ = -1;
+	shcmd->child_gone_ = 0;
+	shcmd->proc_error_ = 0;
+	shcmd->esrch_ = 0;
 	shcmd->envp_ = environ;
 	mode = umask(mode);
 	umask(mode);
@@ -435,13 +443,27 @@ shcmd_apply_redirection(SHCMD * cmd)
 }
 
 int
-shcmd_reap_child(SHCMD * cmd)
+shcmd_reap_child(SHCMD * cmd, int flag)
 {
 	pid_t pid;
-	pid = waitpid(cmd->pid_, &(cmd->status_), 0);
+
+	if (cmd->status_ || cmd->child_gone_) {
+		cmd->child_gone_ = 1;
+		return 0;
+	}
+
+	pid = waitpid(cmd->pid_, &(cmd->status_), flag);
 	if (pid < 0) {
-		fprintf(stderr, "shcmd: waitpid return error for %s\n", 
-		cmd->argv_[0]);
+		if (errno == ECHILD) {
+			E_DEBUG("ECHILD");
+			cmd->child_gone_ = 1;
+		} 
+		cmd->proc_error_ = 1;
+		fprintf(stderr, "shcmd: waitpid return error (pid=%d) for %s: %s\n", 
+			(int)(cmd->pid_), cmd->argv_[0], strerror(errno));
+	} else if (pid > 0) {
+		E_DEBUG3("Normal stop: pid=%d: %s", (int)(cmd->pid_), cmd->argv_[0]);
+		cmd->child_gone_ = 1;
 	}
 	return pid;
 }
@@ -452,6 +474,94 @@ shcmd_cmdvec_wait(SHCMD ** cmd_vec)
 	return shcmd_wait(cmd_vec);
 }
 
+
+int
+shcmd_cmdvec_kill(SHCMD ** cmd_vec, int from, int direction)
+{
+	int ret = 0;
+	int i = from;
+	while(i >= 0 && cmd_vec[i]) {
+		if (cmd_vec[i]->status_ == 0 &&
+		    cmd_vec[i]->esrch_ == 0 &&
+		    cmd_vec[i]->child_gone_ == 0) {
+			ret = kill(cmd_vec[i]->pid_, SIGTERM);
+			if (ret < 0) {
+				if (errno == ESRCH) {
+		    			cmd_vec[i]->esrch_ = 1;
+				}
+			}
+		}
+		if (direction == SHC_DIR_UP) i++;
+		else i--;
+	}
+	return ret;
+}
+
+int
+shcmd_cmdvec_wait2(SHCMD ** cmd_vec)
+{
+	SHCMD ** cmdv = cmd_vec;
+	pid_t pid;
+	int ncmds = 0;
+	int ncmds_exited = 0;
+	int i;
+	int ret;
+	int error_mode = 0;
+	int highest_index_with_error;
+	
+	while(*cmdv) {
+		cmdv++;
+		ncmds++;
+	}
+	E_DEBUG2("No. of commands in pipeline: ncmds = [%d]", ncmds);
+
+	i = 0;
+	highest_index_with_error = 0;
+	do {
+		E_DEBUG("Loop Begin");
+		for(i=ncmds-1; i>=0; i--) {
+			E_DEBUG3("calling reap_child for for cmd_vec[%d]: %s", i, cmd_vec[i]->argv_[0]);
+			ret = shcmd_reap_child(cmd_vec[i], WNOHANG); 
+			E_DEBUG3("finished reap_child for for cmd_vec[%d]: ret=%d", i, ret);
+			if (ret > 0) {
+				E_DEBUG2("good stop for %s", cmd_vec[i]->argv_[0]);
+				ncmds_exited++;
+			} else if (ret == 0) {
+				if (cmd_vec[i]->child_gone_ == 0) {
+					E_DEBUG2("still waiting on pid %d", (int)(cmd_vec[i]->pid_));
+					;
+				}
+				;
+			} else {
+				if (errno == ECHILD) {
+					E_DEBUG2("ECHILD on pid %d", (int)(cmd_vec[i]->pid_));
+					cmd_vec[i]->proc_error_ = 1;
+					ncmds_exited++;
+				} else {
+					E_DEBUG("");
+					fprintf(stderr, "shcmd: waitpid return error (line=%d) for [%d]: %s\n", 
+						__LINE__, (int)(cmd_vec[i]->pid_), cmd_vec[i]->argv_[0]);
+				}
+			}
+			if (cmd_vec[i]->proc_error_) {
+				if (i > highest_index_with_error)
+					highest_index_with_error = i;
+			}
+		}
+		if (highest_index_with_error) {
+			E_DEBUG2("Killing commands at index=%d", highest_index_with_error);
+			shcmd_cmdvec_kill(cmd_vec, highest_index_with_error, SHC_DIR_UP);
+		}
+		highest_index_with_error = 0;
+		E_DEBUG("Sleeping");
+		usleep(100000);
+		E_DEBUG("Loop End");
+	} while (ncmds_exited < ncmds);
+	E_DEBUG("Done");
+	return shcmd_get_exitval(cmd_vec[ncmds-1]);
+}
+
+
 /* Depricated name */
 int
 shcmd_wait(SHCMD ** cmd_vec)
@@ -466,10 +576,10 @@ shcmd_wait(SHCMD ** cmd_vec)
 		ncmds++;
 	}
 	cmdv--;	
-	if (shcmd_reap_child(*cmdv) > 0) {
+	if (shcmd_reap_child(*cmdv, 0) > 0) {
 		ncmds--;	
 		for(i=0; i<ncmds; i++) {
-			pid=shcmd_reap_child(cmd_vec[i]);
+			pid=shcmd_reap_child(cmd_vec[i], 0);
 		}
 	}
 	return shcmd_get_exitval(*cmdv);
