@@ -94,20 +94,19 @@ struct swEvents {
 
 
 /* Source events */
-#define SEVENT(p_fd, p_vlv, p_code, p_arg) swevent_shell_echo(g_evnt, p_fd, \
+#define SEVENT(p_fd, p_vlv, p_code, p_arg) swevent_shell_echo(p_fd, \
 					p_vlv, "source", p_code, \
 					"noused" /*hostname*/, p_arg)
 
 /* Target events */
-#define TEVENT(p_fd, p_vlv, p_code, p_arg) swevent_shell_echo(g_evnt, p_fd, \
+#define TEVENT(p_fd, p_vlv, p_code, p_arg) swevent_shell_echo(p_fd, \
 					p_vlv, "target", p_code, \
 					"noused" /*hostname*/, p_arg)
-
+int swevent_parse_attribute_event(char * line, char ** attribute, char ** value);
 int swevent_is_error(char * line, int * statusp);
 int swevent_get_value(struct swEvents * e, char * msg);
-char * swevent_shell_echo(struct swEvents * e, int fdredir,
-			int verbose_level, char * target,
-			int value, char * host, char * msg);
+char * swevent_shell_echo(int fdredir, int verbose_level, char * target, int value, char * host, char * msg);
 ssize_t swevent_write_rpsh_event(int fd, char * p, int len);
 int swevent_parse_message(char * line, char ** attribute, char ** value);
+struct swEvents * swevent_get_events_array(void);
 #endif
