@@ -1,13 +1,16 @@
 #ifndef swevents_array_h_1203
 #define swevents_array_h_1203
 
+
+/* This file is no longer used, See swevents.c */
+
+/* 
 #include "swevents.h"
 
 #define SWEVENT_LV	1
 #define SWEVENT_LV6	6
-#define SWI_EVENT	1  /* Is an event that takes place in swi.c */
+#define SWI_EVENT	1  
 
-				/* -SW_ERROR means event is always an error */
 struct swEvents eventsArray[] = {
 {"", 0, 0, "", 0, SW_NOTE},
 {"SW_ACCESS_DENIED", 			4, 	SWEVENT_LV, "", 1, SW_ERROR},
@@ -58,10 +61,6 @@ struct swEvents eventsArray[] = {
 {"SW_FILESET_BEGINS",			117,	SWEVENT_LV, "", 1, SW_NOTE},
 {"SW_CONTROL_SCRIPT_BEGINS",		118,	SWEVENT_LV, "", 1, SW_NOTE},
 
-	/*	
-	 * Events 0 - 255 are Posix or are reserved.
-	 * Events >255 are specific to the swbis implementation.
-	 */ 
 
 {"SW_SOURCE_ACCESS_BEGINS", 		260, 	SWEVENT_LV, "", 0, SW_NOTE},
 {"SW_SOURCE_ACCESS_ENDS", 		261, 	SWEVENT_LV, "", 0, SW_ERROR},
@@ -88,5 +87,6 @@ struct swEvents eventsArray[] = {
 {"SWI_GROUP_ENDS",			317,	SWEVENT_LV, "", 1, SW_NOTE},
 {"", -1, 0, "", 0, SW_NOTE}
 };
+*/
 
 #endif
