@@ -43,7 +43,59 @@
 extern struct extendedOptions * optionsArray;
 extern char * CHARTRUE;
 
+static char * utilnames[] = {
+	"swask",       /* SWC_U_A  (1 << 0) */
+	"swcopy",      /* SWC_U_C  (1 << 1) */
+	"swinstall",   /* SWC_U_I  (1 << 2) */
+	"swconfig",    /* SWC_U_G  (1 << 3) */
+	"swlist",      /* SWC_U_L  (1 << 4) */
+	"swmodify",    /* SWC_U_M  (1 << 5) */
+	"swpackage",   /* SWC_U_P  (1 << 6) */
+	"swremove",    /* SWC_U_R  (1 << 7) */
+	"swverify",    /* SWC_U_V  (1 << 8) */
+	"",            /* SWC_U_X  (1 << 9) */
+	NULL };
 
+static
+int
+find_pow(int flag)
+{
+	int i = 1;
+	if (flag <= 1) return 0;
+
+	while (flag/2 > 1) {
+		flag = flag >> 1;
+		i++;
+	}
+	return i;
+}
+
+static
+int
+check_applicability(struct extendedOptions * opta, enum eOpts nopt)
+{
+	int bit;
+	int index;
+	char * cu;
+	int ret;
+	char ** names = utilnames;
+	int ap_mask;	
+
+	ap_mask = opta[nopt].app_flags;
+
+	cu = swlib_utilname_get();
+	
+	while (*names && strcmp(cu, *names)) {
+		names++;
+	}
+	if (!(*names)) return 1;
+	index = (int)(names - utilnames);
+	bit = 1 << index;
+	ret = ! (ap_mask & bit);
+	if (ret)
+		fprintf(stderr, "%s: option not valid: %s\n", cu, opta[nopt].optionNameM);
+	return ret;
+}
 
 static
 void
@@ -92,6 +144,9 @@ i_set_opta(int optsetflag, struct extendedOptions * opta,
 		swlib_utilname_get(), opta[nopt].optionNameM);
 		exit(1);
 	}
+
+	/* check_applicability(opta, nopt); */
+
 	opta[nopt].option_setM = (char)optsetflag;
 	if (value) {
 		opta[nopt].valueM = strdup(value);
@@ -442,21 +497,18 @@ getExtendedOption(char * optionname, struct extendedOptions * peop,
 	return NULL; /* error, option not found. */
 }
 
-
 void
 set_opta(struct extendedOptions * opta, enum eOpts nopt, char * value)
 {
 	i_set_opta(1, opta, nopt, value);
 }
 
-
 void
 set_opta_initial(struct extendedOptions * opta, enum eOpts nopt, char * value)
 {
 	i_set_opta(0, opta, nopt, value);
 }
 
-
 char *
 swbisoption_get_opta(struct extendedOptions * opta, enum eOpts nopt)
 {
@@ -655,7 +707,7 @@ swextopt_combine_directory(STROB * result, char * soc_spec, char * directory)
 		retval = -1;
 	}
 	else if (
-		strlen(soc_spec) > 1 && *soc_spec == ':' ||
+		(strlen(soc_spec) > 1 && *soc_spec == ':') ||
 		0
 	) {
 		/* 
