@@ -39,18 +39,30 @@ struct extendedOptions {
 		int app_flags;
 };
 
-#define SWC_A  (1 << 0) 	/* applicability_flags   swask     */
-#define SWC_C  (1 << 1) 	/* applicability_flags   swcopy    */
-#define SWC_I  (1 << 2) 	/* applicability_flags   swinstall */
-#define SWC_G  (1 << 3) 	/* applicability_flags   swconfig  */
-#define SWC_L  (1 << 4) 	/* applicability_flags   swlist    */
-#define SWC_M  (1 << 5) 	/* applicability_flags   swlist    */
-#define SWC_P  (1 << 6) 	/* applicability_flags   swpackage */
-#define SWC_R  (1 << 7) 	/* applicability_flags   swremove  */
-#define SWC_V  (1 << 8) 	/* applicability_flags   swverify  */
-#define SWC_X  (1 << 9) 	/* applicability_flags   not applicable  */
+#define SWC_U_ASK		SWC_U_A
+#define SWC_U_COPY		SWC_U_C 
+#define SWC_U_INSTALL		SWC_U_I 
+#define SWC_U_CONFIG		SWC_U_G
+#define SWC_U_LIST		SWC_U_L 
+#define SWC_U_MODICY		SWC_U_M 
+#define SWC_U_PACKAGE		SWC_U_P 
+#define SWC_U_REMOVE		SWC_U_R 
+#define SWC_U_VERIFY		SWC_U_V 
+#define SWC_U_NOTAPPLICABLE	SWC_U_X 
 
-enum eOpts {	/* NOTE: the order must match the optionsArray */
+#define SWC_U_A  (1 << 0) 	/* applicability_flags   swask     */
+#define SWC_U_C  (1 << 1) 	/* applicability_flags   swcopy    */
+#define SWC_U_I  (1 << 2) 	/* applicability_flags   swinstall */
+#define SWC_U_G  (1 << 3) 	/* applicability_flags   swconfig  */
+#define SWC_U_L  (1 << 4) 	/* applicability_flags   swlist    */
+#define SWC_U_M  (1 << 5) 	/* applicability_flags   swmodify  */
+#define SWC_U_P  (1 << 6) 	/* applicability_flags   swpackage */
+#define SWC_U_R  (1 << 7) 	/* applicability_flags   swremove  */
+#define SWC_U_V  (1 << 8) 	/* applicability_flags   swverify  */
+#define SWC_U_X  (1 << 9) 	/* applicability_flags   not applicable  */
+
+enum eOpts {	/* NOTE: the order must match the optionsArray 
+		  found in swsupplib/misc/swcommon_options.h */
 	SW_E_allow_downdate,
 	SW_E_allow_incompatible,
 	SW_E_allow_multiple_versions,
@@ -121,8 +133,10 @@ enum eOpts {	/* NOTE: the order must match the optionsArray */
 	SW_E_swbis_remote_shell_client,
 	SW_E_swbis_install_volatile,
 	SW_E_swbis_volatile_newname,
+	SW_E_swbis_any_format,
 	SW_E_swbis_last_option
-	};  /* NOTE: the order must match the optionsArray */
+	};  /* NOTE: the order must match the optionsArray
+		 found in swsupplib/misc/swcommon_options.h*/
 
 
 void debug_writeBooleanExtendedOptions(int ofd, struct extendedOptions * opta);
