@@ -48,6 +48,8 @@
 #endif
 #include "swfork.h"
 #include "swgp.h"
+#include "swlib.h"
+#include "swutillib.h"
 #include "swutilname.h"
         			
 
