@@ -1,6 +1,5 @@
 /* swheader.h -  Routines for reading the parser output.
- $Id: swheader.h,v 1.18 2000/10/14 19:50:48 jhl Exp jhl $
-                 (i.e. 'swbisparse -n' style output.)
+                 in the 'swbisparse -n' style.
 
  Copyright (C) 1998, 1999  Jim Lowe <jhlowe@acm.org>
 
