@@ -1,5 +1,4 @@
-/* $Id: swheaderline.h,v 1.2 2000/03/23 23:12:24 jhl Exp jhl $
- swheaderline.h  --
+/* swheaderline.h
  
  Copyright (C) 1998, 1999  Jim Lowe <jhlowe@acm.org>
 
