@@ -36,6 +36,7 @@
 #include "swinstall.h"
 #include "atomicio.h"
 #include "ls_list.h"
+#include "swverid.h"
 #include "swevents.h"
 #include "swicat.h"
 
@@ -83,7 +84,7 @@ form_session_options_filename(STROB * tmp, SWI * swi)
 	 */
 	swlib_squash_trailing_slash(strob_str(tmp));
 	swlib_squash_double_slash(strob_str(tmp));
-	if (swlib_is_clean_absolute_path(strob_str(tmp)))
+	if (swlib_check_clean_absolute_path(strob_str(tmp)))
 		SWLIB_FATAL("internal error");
 	return;
 }
@@ -132,7 +133,7 @@ form_absolute_control_dir(STROB * tmp, SWI * swi, char * control_script_pkg_dir,
 	 */
 	swlib_squash_trailing_slash(strob_str(tmp));
 	swlib_squash_double_slash(strob_str(tmp));
-	if (swlib_is_clean_absolute_path(strob_str(tmp)))
+	if (swlib_check_clean_absolute_path(strob_str(tmp)))
 		SWLIB_FATAL("internal error");
 
 	/*
@@ -153,7 +154,7 @@ static
 void 
 write_state(STROB * buf, SWI_XFILE * xx, int do_if_active)
 {
-	if (do_if_active && !(xx->is_activeM)) return;
+	if (do_if_active && !(xx->baseM.is_activeM)) return;
 	if (strcmp(xx->stateM, SW_STATE_UNSET)) {
 		strob_sprintf(buf, STROB_DO_APPEND,  "    " SW_A_state " %s\n", xx->stateM);
 	}
@@ -203,6 +204,16 @@ add_env_entry(char  * name, char * value, STROB * buf)
 		strob_sprintf(buf, STROB_DO_APPEND, "%s=\"%s\"\n", name, s); 
 		strob_sprintf(buf, STROB_DO_APPEND, "export %s\n", name); 
 	}
+}
+
+static
+int
+write_dependency_assertion_script(SWI * swi, SWVERID * dep_spec, STROB * buf)
+{
+
+
+
+
 }
 
 int
@@ -267,7 +278,7 @@ swicat_isf_control_script(STROB * buf, SWI_CONTROL_SCRIPT * xx, int do_if_active
 {
 	/* if (do_if_active && !(xx->is_activeM)) return 0; */
 	strob_sprintf(buf, STROB_DO_APPEND, SW_A_control_file "\n");
-	strob_sprintf(buf, STROB_DO_APPEND, "\t" SW_A_tag " %s\n", xx->tagM);
+	strob_sprintf(buf, STROB_DO_APPEND, "\t" SW_A_tag " %s\n", xx->baseM.tagM);
 	strob_sprintf(buf, STROB_DO_APPEND, "\t" SW_A_result " %s\n", swi_control_script_posix_result(xx));
 	if (xx->resultM >= 0)
 		strob_sprintf(buf, STROB_DO_APPEND, "\t" "return_code" " %d\n", xx->resultM);
@@ -281,9 +292,9 @@ swicat_isf_fileset(SWI * swi, STROB * buf, SWI_XFILE * xfile, int do_if_active)
 
 	strob_sprintf(buf, STROB_DO_APPEND, SW_A_fileset "\n");
 
-	write_attributes(buf, SWI_INDEX_HEADER(swi), xfile->INDEX_header_indexM);
+	write_attributes(buf, SWI_INDEX_HEADER(swi), xfile->baseM.header_indexM);
 	write_state(buf, xfile, do_if_active);
-	write_times(buf, (SWI_BASE *)xfile, 1 /* do_if_active */);
+	write_times(buf, (SWI_BASE *)&(xfile->baseM), 1 /* do_if_active */);
 
 	/*
 	{
@@ -314,9 +325,9 @@ swicat_isf_product(SWI * swi, STROB * buf, SWI_PRODUCT * prod, int do_if_active)
 	/* if (do_if_active && !(prod->is_activeM)) return 0; */
 	strob_sprintf(buf, STROB_DO_APPEND, SW_A_product "\n");
 		
-	write_attributes(buf, SWI_INDEX_HEADER(swi), prod->header_indexM);
+	write_attributes(buf, SWI_INDEX_HEADER(swi), prod->baseM.header_indexM);
 
-	write_times(buf, (SWI_BASE *)prod, 1 /* do_if_active */);
+	write_times(buf, (SWI_BASE *)&(prod->baseM), 1 /* do_if_active */);
 	/* strob_sprintf(buf, STROB_DO_APPEND, SW_A_all_filesets "%s\n", "" ); */
 
 	/* ------------------------------------------------------ */
@@ -325,7 +336,7 @@ swicat_isf_product(SWI * swi, STROB * buf, SWI_PRODUCT * prod, int do_if_active)
 	/*
 	{
 		swheader_store_state(swheader);
-		swheader_set_current_offset(swheader, prod->header_indexM);
+		swheader_set_current_offset(swheader, prod->baseM.header_indexM);
 		while((line=swheader_get_next_attribute(swheader)))
 			swheaderline_write_debug(line, STDERR_FILENO);
 		swheader_restore_state(swheader);
@@ -454,18 +465,18 @@ swicat_construct_controlsh_taglist(SWI * swi, char * sw_selections, STROB * list
 	for(i=0; i<SWI_MAX_OBJ; i++) {
 		product = package->swi_coM[i];
 		if (product) {
-			SWLIB_ASSERT(product->tagM != NULL);
-			strob_strcpy(tmp, product->tagM);
-			if (swlib_is_clean_path(product->tagM)) SWLIB_ASSERT(0);
+			SWLIB_ASSERT(product->baseM.tagM != NULL);
+			strob_strcpy(tmp, product->baseM.tagM);
+			if (swlib_check_clean_path(product->baseM.tagM)) SWLIB_ASSERT(0);
 			strob_sprintf(list, STROB_DO_APPEND, "%s", strob_str(tmp));
 			for(j=0; j<SWI_MAX_OBJ; j++) {
 				fileset = product->swi_coM[j];
 				if (fileset) {
-					SWLIB_ASSERT(fileset->tagM != NULL);
-					if (swlib_is_clean_path(fileset->tagM)) SWLIB_ASSERT(0);
-					strob_strcpy(tmp, product->tagM);
+					SWLIB_ASSERT(fileset->baseM.tagM != NULL);
+					if (swlib_check_clean_path(fileset->baseM.tagM)) SWLIB_ASSERT(0);
+					strob_strcpy(tmp, product->baseM.tagM);
 					strob_strcat(tmp, ".");
-					strob_strcat(tmp, fileset->tagM);
+					strob_strcat(tmp, fileset->baseM.tagM);
 					strob_sprintf(list, STROB_DO_APPEND, " %s", strob_str(tmp));
 				} else break;
 			}
