@@ -55,9 +55,6 @@
 #define SWICOL_E_DEBUG3(arg, arg1, arg2)
 #endif 
 
-extern struct swEvents eventsArray[];
-static struct swEvents * g_evnt = eventsArray;
-
 static
 int
 set_selected_index(SWICOL * swicol, int first_current_event)
@@ -178,6 +175,7 @@ print_task_script(SWICOL * swicol, STROB * command, unsigned long int size, char
 	STROB * enddesc = strob_open(32);
 
 	int blocks = (int)(size / 512);
+	
 	if (size % 512) {
 		/*
 		 * size must be a whole number of 512 blocks.
