@@ -1,5 +1,4 @@
-/* $Id: swlib.c,v 1.23 2000/10/15 04:36:42 jhl Exp jhl $ 
- * swlib.c - General Purpose Routines.
+/* swlib.c - General Purpose Routines.
  */
 
 /*
@@ -125,7 +124,7 @@ process_all_escapes(char * src)
 }
 
 int
-doif_writeap(int fd, STROB * buffer, char * format, va_list * pap)
+swlib_doif_writeap(int fd, STROB * buffer, char * format, va_list * pap)
 {
 	int ret;
 	int aret;
@@ -1713,7 +1712,7 @@ swlib_shcmd_output_fd(SHCMD ** cmdvec)
 		close(ot[0]);
 		shcmd_set_dstfd(lastcmd, ot[1]);
 		shcmd_cmdvec_exec(cmdvec);
-		shcmd_cmdvec_wait(cmdvec);
+		shcmd_cmdvec_wait2(cmdvec);
 		close(ot[1]);
 		_exit(0);
 	}
