@@ -1,5 +1,4 @@
-/* $Id: swvarfs.c,v 1.1 2002/05/14 02:39:26 jhl Exp jhl $
-   swvarfs.c  --  File I/O calls on an archive stream or directory file.
+/* swvarfs.c  --  File I/O calls on an archive stream or directory file.
 
    Copyright (C) 2003  Jim Lowe 
    All Rights Reserved.
@@ -28,6 +27,7 @@
 #include "swvarfs.h"
 #include "strar.h"
 #include "swlib.h"
+#include "fnmatch_u.h"
 
 #include "debug_config.h"
 #ifdef SWVARFSNEEDDEBUG
