@@ -1,5 +1,4 @@
-/* $Id: swverid.c,v 1.12 2000/03/28 00:39:49 jhl Exp jhl $
- *  swverid.c: POSIX-7.2 Object Identification Routines.
+/*  swverid.c: POSIX-7.2 Object Identification Routines.
  */
 
 /*
@@ -32,6 +31,7 @@
 #include "strob.h"
 #include "swlib.h"
 #include "swutilname.h"
+#include "misc-fnmatch.h"
 #include "swverid.h"
 
 static char * rel_op_array[] = {
@@ -270,7 +270,7 @@ compare_taglist(SWVERID * target, SWVERID * candidate)
 	 * 'candidtate' may contain patterns
 	 */
 
-
+	return -1;
 }
 
 static
@@ -975,7 +975,7 @@ swverid_add_verid(SWVERID * swverid, struct VER_ID  * verid) {
 }
 
 char *
-swverid_print(SWVERID * swverid, char * buf, int buflen)
+swverid_print(SWVERID * swverid, STROB * buf)
 {
 	char * s;
 	int i = 0;
@@ -1004,13 +1004,8 @@ swverid_print(SWVERID * swverid, char * buf, int buflen)
 		next = next->nextM; 
 	}
 
-	if ((int)strlen(strob_str(version)) <= buflen - 1) {
-		strcpy(buf, strob_str(version));
-		ret = buf;
-	} else {
-		buf[0] = '\0';
-		ret = NULL;
-	}
+	strob_strcpy(buf, strob_str(version));
+	ret = strob_str(buf);
 	strob_close(version);
 	return ret;
 }
@@ -1018,9 +1013,8 @@ swverid_print(SWVERID * swverid, char * buf, int buflen)
 char *
 swverid_show_object_debug(SWVERID * swverid, STROB * buf)
 {
-	strob_set_length(buf, 100);
 	strob_strcpy(buf, "");
-	if (! swverid_print(swverid, strob_str(buf), 99))
+	if (! swverid_print(swverid, buf))
 		return "";
 	strob_strcat(buf, "\n");
 	strob_sprintf(buf, 1,
