@@ -1,5 +1,4 @@
-/* $Id: swverid.h,v 1.11 2000/03/26 16:44:00 jhl Exp jhl $
- *  swverid.h -- IEEE 1387.2 Version structure.
+/*  swverid.h -- IEEE 1387.2 Version structure.
  */ 
 
 /*
@@ -27,6 +26,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include "swsdflt.h"
+#include "strob.h"
 #include "cplob.h"
 #include "swuts.h"
 
@@ -117,7 +117,7 @@ typedef struct {				/* Object Version Spec */
 SWVERID * 	swverid_open            	(char * object_keyword, char * swversion_string);
 void      	swverid_close           	(SWVERID * swverid);
 void 		swverid_set_namespace		(SWVERID * swverid, char * object_keyword);
-char * 		swverid_print			(SWVERID * swverid, char * buf, int buflen);
+char * 		swverid_print			(SWVERID * swverid, STROB * buf);
 int		swverid_add_attribute		(SWVERID * swverid, char * object_keyword, char * keyw, char * value);
 int       	swverid_make_ver_id		(SWVERID * swverid, char * attr_name, char * value, char * rel_op);
 struct VER_ID*	swverid_get_ver_id		(SWVERID * swverid, char * keyword, struct VER_ID * ver_id);
