@@ -46,6 +46,8 @@
 YYSTYPE yylval;
 static int verboseG;
 
+#define GPG_STATUS_PREFIX 	"[GNUPG:] "
+
 static int
 usage(FILE * file, char * name)
 {
@@ -110,12 +112,53 @@ enforce_tar_format(int format)
 	}
 }
 
+static
+int
+validate_gpg_status(char * gpg_status_lines)
+{
+	STROB * tmp;
+	char * line;
+	int good_count;
+	int bad_count;
+
+	tmp = strob_open(100);
+
+	good_count=0;
+	bad_count=0;
+	line = strob_strtok(tmp, gpg_status_lines, "\n\r");
+        while(line) {
+		/* fprintf(stderr, "%s\n", line); */
+		if (strstr(line, GPG_STATUS_PREFIX) == line) {
+			if (strstr(line, GPG_STATUS_PREFIX "GOODSIG")) {
+				good_count++;
+			} else if (strstr(line, "BADSIG")) {
+				bad_count++;
+			} else if (strstr(line, "ERRSIG")) {
+				bad_count++;
+			} else if (strstr(line, "EXPSIG")) {
+				bad_count++;
+			} else if (strstr(line, "NODATA")) {
+				bad_count++;
+			} 
+		} else {
+			return 1;
+		}
+		line = strob_strtok(tmp, NULL, "\n\r");
+        }
+	strob_close(tmp);
+	if (good_count == 1 && bad_count == 0)
+		return 0;
+	else
+		return 1;
+}
+
 static
 int
 run_checksig(char * sigfilename, char * thisprog,
 		char * filearg, char * gpg_prog, int uverbose,
 		char * which_sig_arg)
 {
+	int ret;
 	int ret1;
 	int ret2;
 	char * absname;
@@ -157,75 +200,25 @@ run_checksig(char * sigfilename, char * thisprog,
 			"%s: using GNU Privacy Guard : %s\n", swlib_utilname_get(), absname);
 	}
 	shcmd_add_arg(cmd[1], absname);		/* GPG command */
+	shcmd_add_arg(cmd[1], "--status-fd=1");
 	shcmd_add_arg(cmd[1], "--verify");
 	shcmd_add_arg(cmd[1], sigfilename); 	/* Other end of FIFO */
 	shcmd_add_arg(cmd[1], "-");
 	if (uverbose < 2) {
 		shcmd_set_errfile(cmd[1], "/dev/null");
 	}
-	shcmd_cmdvec_exec(cmd);
-
-	pid1[0] = shcmd_get_pid(cmd[0]);  /* arf2arf pid */
-	pid2[0] = shcmd_get_pid(cmd[1]);  /* gpg pid */
-
-	/*
-	* Wait on the arf2arf process.
-	*/
-	swlib_wait_on_all_pids(pid1, 1, status1, 0, verboseG);
-
-	/*
-	* analyze the status of the arf2arf process.
-	*/
-
-	if (WIFEXITED(status1[0]) == 0 || 
-			((ret1=WEXITSTATUS(status1[0])) && ret1 != 63)) {
-		/*
-		* If there is a bad outcome of arf2arf process, then
-		* Kill gpg.
-		*/
-		if (uverbose > 3) 
-			fprintf(stderr, 
-	"arf2arf: run_checksig error : child: exited=%d exitstatus=%d\n",
-			WIFEXITED(status1[0]), WEXITSTATUS(status1[0]));
-		kill(pid2[0], SIGTERM);
-		return 22;
-	}
-
-	/*
-	* 63 is the gzip warning indicator, don't react to it.
-	*/
-	
-	/*
-	* Wait on the gpg process.
-	*/
-	swlib_wait_on_all_pids(pid2, 1, status2, 0, verboseG);
-
-	/*
-	* analyze the status of the arf2arf process.
-	*/
-	if (WIFEXITED(status1[0]) == 0) {
-		ret1 = 7;
-	} else {
-		ret1 = WEXITSTATUS(status1[0]);
-	}
-
-	/*
-	* analyze the status of the GPG process.
-	*/
-	if (WIFEXITED(status2[0]) == 0) {
-		ret2 = 10;
-	} else {
-		ret2 = WEXITSTATUS(status2[0]);
-	}
+	/* shcmd_set_errfd(cmd[1], 1); */
+	strob_strcpy(tmp, "");
+	swlib_shcmd_output_strob(tmp, cmd);
 
 	shcmd_close(cmd[0]);
 	shcmd_close(cmd[1]);
-	if (ret2) 
-		return ret2;
-	else if (ret1) 
-		return ret1;
-	else
-		return 0;
+
+	ret = validate_gpg_status(strob_str(tmp));
+	if (uverbose >= SWC_VERBOSE_3) {
+		fprintf(stderr, "%s", strob_str(tmp));
+	}
+	return ret;
 }
 
 int
@@ -439,8 +432,9 @@ main (int argc, char *argv[])
 		ret = run_checksig(sigfilename, 
 				SWBISLIBEXECDIR "/swbis/arf2arf", 
 					filearg, gpg_prog, uverbose, which_sig_arg);
-		if (uverbose>3) fprintf(stderr, 
-				"do_checksig returned %d\n", ret);
+		if (uverbose>5) fprintf(stderr, 
+				"%s: do_checksig returned %d\n", swlib_utilname_get(), ret);
+		if (ret < 0) ret = 1;
 		exit(ret);
 	}
 
@@ -515,10 +509,10 @@ main (int argc, char *argv[])
 				sigfilename, 
 				uverbose,
 				which_sig /*last signature*/); 
-		if (uverbose >= 3) {
+		if (uverbose >= 5) {
 			fprintf(stderr,
-				"taruib_write_signedfile_if returned %d\n",
-							ret);
+				"%s: taruib_write_signedfile_if returned %d\n",
+							swlib_utilname_get(), ret);
 		}
 	} else if (adjunct_store_sign) {
 		enforce_tar_format(detected_format);
@@ -607,15 +601,13 @@ main (int argc, char *argv[])
 	iret = xformat_close(xformat);
 	if (fd != STDIN_FILENO) close(fd);
 
-	if (uverbose >= 3) {
-		fprintf(stderr, "%s : ret=%d\n", argv[0], ret);
-		fprintf(stderr, "%s : iret=%d\n", argv[0], iret);
+	if (uverbose >= 5) {
+		fprintf(stderr, "%s : ret=%d\n", swlib_utilname_get(), ret);
+		fprintf(stderr, "%s : iret=%d\n", swlib_utilname_get(), iret);
+		fprintf(stderr, "%s : exiting with %d\n", swlib_utilname_get(), ret);
 	}
 	if (ret == 0) ret = iret;
 
-	if (uverbose >= 3) {
-		fprintf(stderr, "%s : exiting with %d\n", argv[0], ret);
-	}
 	/* close(STDERR_FILENO); */
 	if (ret < 0) ret = 1;
 	exit(ret);
