@@ -4,6 +4,8 @@
 #include <unistd.h>
 #include "taru.h"
 #include "swparser_global.h"
+#include "swevents_array.h"
+#include "swcommon_options.h"
 
 int 
 main (int argc, char ** argv ) {
