@@ -49,11 +49,6 @@
 #define SWSWI_E_DEBUG3(arg, arg1, arg2)
 #endif 
 
-/*
-extern struct swEvents eventsArray[];
-static struct swEvents * g_evnt = eventsArray;
-*/
-
 static 
 SWPATH_EX *
 swi_get_last_swpath_ex(SWI * swi)
@@ -140,6 +135,12 @@ need_new_pfiles(SWI * swi)
 	return 0;
 }
 
+void
+swi_set_utility_id(SWI * swi, int swc_u_id)
+{
+	swi->swc_idM = swc_u_id;
+}
+
 int
 swi_is_definition_file(SWI * swi, char * name, int *swdeffile_type_p)
 {
@@ -1134,7 +1135,8 @@ swi_do_decode(SWI * swi, SWUTIL * swutil,
 	int is_seekable,
 	int do_debug_events,
 	int verboseG,
-	struct sw_logspec * g_logspec
+	struct sw_logspec * g_logspec,
+	int uinfile_open_flags
 	)
 {
 	int ret;
@@ -1145,23 +1147,52 @@ swi_do_decode(SWI * swi, SWUTIL * swutil,
 	UINFORMAT * uinformat;
 	SWVARFS * swvarfs;
 	char * rpm_newname;
+	int format;
+	int flags;
 
 	SWLIB_ASSERT(source_fd0 >= 0);
 	swlib_doif_writef(verboseG, SWC_VERBOSE_IDB,
 					g_logspec, swutil->swu_efdM, 
 					"run audit: start setup_xformat\n");
 
-	xformat = swutil_setup_xformat(swutil, target_fd1,
-			source_fd0, source_path, opta, is_seekable, verboseG, g_logspec);
-	if (!xformat) {
-		/* redundant LC_RAISE(SIGTERM); */
+	format = arf_ustar;
+
+	/* Create the xformat object */
+        xformat = xformat_open( -1 /* STDIN_FILENO */, -1 /* target_fd1 */, format);
+
+	/* FIXME  the open policy described by flags may should be
+	   forced up a level so the top level utility can
+	   control the policy */
+
+	if (uinfile_open_flags < 0) {
+		flags = UINFILE_DETECT_FORCEUXFIOFD |
+			UINFILE_DETECT_UNCPIO |
+			UINFILE_DETECT_IEEE;
+	} else {
+		flags = uinfile_open_flags;
+	}
+	
+	/* Now, open the package */
+
+	xformat = swutil_setup_xformat(swutil,
+			xformat,
+			source_fd0,
+			source_path,
+			opta,
+			is_seekable,
+			verboseG,
+			g_logspec,
+			flags);
+
+	if (xformat == (XFORMAT*)NULL) {
 		return -1;
 	}
+	
+	/* The package is now opened and partially decoded */
+
 	swlib_doif_writef(verboseG, SWC_VERBOSE_IDB2, g_logspec, swutil->swu_efdM, 
 				"run audit: finished setup_xformat\n");
 
-	SWLIB_ASSERT(xformat != (XFORMAT*)NULL);
-
 	xformat_set_ofd(xformat, target_fd1);
 
 	swlib_doif_writef(verboseG, SWC_VERBOSE_IDB2, g_logspec, swutil->swu_efdM, 
@@ -1209,7 +1240,7 @@ swi_do_decode(SWI * swi, SWUTIL * swutil,
 	}	
 	ifd = xformat_get_ifd(xformat);	
 	swi->optaM = (void*)opta;
-	swi->swc_idM = SWC_I; 	/* swinstall */
+	/* swi->swc_idM = SWC_U_I; */
 	swi->debug_eventsM = do_debug_events;
 	
 	/*
