@@ -162,7 +162,7 @@ swi_file_member_create(void)
 	SWI_FILE_MEMBER * s = (SWI_FILE_MEMBER *)malloc(
 					sizeof(SWI_FILE_MEMBER));
 	swi_com_assert_pointer((void*)s, __FILE__, __LINE__);
-	swi_base_init((SWI_BASE *)s, SWI_I_TYPE_AFILE, NULL, NULL);
+	swi_vbase_init(s, SWI_I_TYPE_AFILE, NULL, NULL);
 	s->refcountM = 1;
 	s->pathnameM = NULL;
 	s->lenM  = -1;
@@ -173,7 +173,7 @@ swi_file_member_create(void)
 void
 swi_control_script_delete(SWI_CONTROL_SCRIPT * s)
 {
-	if (s->tagM) free(s->tagM);
+	if (s->baseM.tagM) free(s->baseM.tagM);
 	swi_file_member_delete(s->afileM);
 	free(s);
 }
@@ -186,7 +186,7 @@ swi_control_script_create(void)
 	s = (SWI_CONTROL_SCRIPT *)malloc(sizeof(SWI_CONTROL_SCRIPT));
 	swi_com_assert_pointer((void*)s, __FILE__, __LINE__);
 
-	swi_base_init((SWI_BASE *)s, SWI_I_TYPE_SCRIPT, NULL, NULL);
+	swi_vbase_init(s, SWI_I_TYPE_SCRIPT, NULL, NULL);
 
 	s->afileM = NULL; /* swi_file_member_create(); */
 	s->resultM = SWI_RESULT_UNDEFINED;
@@ -251,7 +251,7 @@ swi_afile_write_script_cases(SWI_SCRIPTS * scripts, STROB * buf)
 			/*
 			 * Mark the tag as being used
 			 */
-			set_is_ieee_control_script(control_script->tagM, 1);
+			set_is_ieee_control_script(control_script->baseM.tagM, 1);
 
 			/*
 			 * Now write the shell case statement fragment
@@ -268,8 +268,8 @@ swi_afile_write_script_cases(SWI_SCRIPTS * scripts, STROB * buf)
 				"\t\t\texport SW_CONTROL_DIRECTORY=\"${SW_ROOT_DIRECTORY}/${SW_CATALOG}/${SWBIS_CATALOG_ENTRY}/%s/%s\"\n"
 				"\t\t\tSWBCS_SCRIPT_NAME=\"%s\"\n"
 				"\t\t\t;;\n",
-				control_script->tagM,
-				control_script->tagM,
+				control_script->baseM.tagM,
+				control_script->baseM.tagM,
 				SWINSTALL_INCAT_NAME,
 				control_script->afileM->pathnameM,
 				name
