@@ -53,9 +53,9 @@ loop_and_record(SWHEADER * INDEX, char * object_keyword, STRAR * list,
 	int count = 0;
 	int retval;
 
-	obj = swheader_get_object_by_tag(INDEX, object_keyword, "");
+	obj = swheader_get_object_by_tag(INDEX, object_keyword, "*");
 	while(obj) {
-		attrline = swheader_get_attribute_single_value(INDEX, "tag");
+		attrline = swheader_get_attribute(INDEX, SW_A_tag);
 		if (!attrline) {
 			fprintf(stderr, "no tag found for %s\n", object_keyword);
 			retval = 20;
@@ -64,13 +64,13 @@ loop_and_record(SWHEADER * INDEX, char * object_keyword, STRAR * list,
 		value = swheaderline_get_value(attrline, NULL);
 		strar_add(list, value);
 
-		attrline = swheader_get_attribute_single_value(INDEX, SW_A_vendor_tag);
+		attrline = swheader_get_attribute(INDEX, SW_A_vendor_tag);
 		if (attrline) {
 			value = swheaderline_get_value(attrline, NULL);
 			if (vendor_list) strar_add(vendor_list, value);
 		}
 	
-		attrline = swheader_get_attribute_single_value(INDEX, SW_A_revision);
+		attrline = swheader_get_attribute(INDEX, SW_A_revision);
 		if (!attrline) {
 			fprintf(stderr, "no revision found for %s\n", object_keyword);
 			retval = 23;
@@ -81,7 +81,7 @@ loop_and_record(SWHEADER * INDEX, char * object_keyword, STRAR * list,
 			strar_add(revision_list, value);
 	
 		swheader_get_next_object(INDEX, (int)UCHAR_MAX, (int)UCHAR_MAX);
-		obj = swheader_get_object_by_tag(INDEX, object_keyword, "");
+		obj = swheader_get_object_by_tag(INDEX, object_keyword, "*");
 		count++;
 	}
 	return count;
@@ -184,14 +184,14 @@ swi_distdata_resolve(SWI * swi, SWI_DISTDATA * part1,
 	 */
 
 	swheader_reset(INDEX);
-	obj = swheader_get_object_by_tag(INDEX, SW_A_distribution, "");
+	obj = swheader_get_object_by_tag(INDEX, SW_A_distribution, "*");
 	if (!obj) {
 		retval = 40;
 		return retval;
 	}
 	offset = swheader_get_current_offset(INDEX);
 
-	attrline = swheader_get_attribute_single_value(INDEX, "tag");
+	attrline = swheader_get_attribute(INDEX, SW_A_tag);
 	if (!attrline) { 
 		/*
 		 * dist.tag is optional
