@@ -36,24 +36,13 @@
 #define SWI_XFILE_TYPE_PFILES		2
 
 typedef struct {		/* The fileset/pfiles/dfiles  object	*/
-
-				/* This *Must* match SWI_BASE		*/
-	unsigned char id_startM;  /* Always SWI_BASE_ID_BEGIN */
-	char type_idM;		/* 'C'					*/
-	int is_activeM;
-	char * tagM;		/* the fileset tag			*/
-	time_t create_timeM;
-	time_t mod_timeM;
-	int INDEX_header_indexM; /* index in the global INDEX for this   */
-	SWHEADER  * global_indexM;	/* Global INDEX access object	*/
-	unsigned char id_endM; /* Always SWI_BASE_ID_END */
-
+	SWI_BASE baseM;
 	char * package_pathM;	/* The package path for this object	*/
 	char * control_dirM;	/* the fileset control dir		*/
 	int typeM;		/* type: 0 fileset; 1 dfiles; 2 pfiles  */
 	char stateM[12];	/* fileset state 			*/
 	SWI_SCRIPTS * swi_scM;	/* control scripts 			*/
-	SWHEADER * headerM;	/* INFO file access object		*/
+	SWHEADER * info_headerM; /* INFO file access object		*/
 	int INFO_header_indexM;	/* INFO access object index             */
 	CPLOB * archive_filesM;	/* List of pointers to SWI_FILE_MEMBERs */
 	int swdef_fdM;		/* INFO file uxfio fd			*/
