@@ -1,5 +1,4 @@
-/* $Id: taruib.c,v 1.3 2000/10/14 15:41:28 jhl Exp jhl $
-   taruib.c - write the catalog and storage byte streams.
+/* taruib.c - write the catalog and storage byte streams.
 
    Copyright (C) 2003 Jim Lowe
 
@@ -29,6 +28,7 @@
 #include "swgp.h"
 #include "swi.h"
 #include "xformat.h"
+#include "fnmatch_u.h"
 
 #include "debug_config.h"
 #ifdef TARUIBNEEDDEBUG
