@@ -1,5 +1,4 @@
-/* $Id$
-   taruib_i.c - 
+/* taruib_i.c - 
 
    Copyright (C) 2004 Jim Lowe
 
@@ -30,6 +29,7 @@
 #include "swi.h"
 #include "swutilname.h"
 #include "xformat.h"
+#include "fnmatch_u.h"
 
 #include "debug_config.h"
 #ifdef TARUIBNEEDDEBUG
@@ -907,7 +907,7 @@ taruib_write_signedfile_if(void * vp, int ofd, char * sigfile,
 		return 3;
 	}
 
-	if (verbose >= 1) {
+	if (verbose >= SWC_VERBOSE_2) {
 		fprintf(stderr, "%s: Archive digest: ", swlib_utilname_get());
 	}
 
@@ -1050,7 +1050,7 @@ taruib_write_signedfile_if(void * vp, int ofd, char * sigfile,
 	if (strlen(md5digbuf) >= 32 && 
 			strncmp(calc_md5digbuf, md5digbuf, 32) == 0) {
 		pri_ret = 0;
-		if (verbose >= 1) {
+		if (verbose >= SWC_VERBOSE_2) {
 			fprintf(stderr, "md5 OK (Good)\n");
 		}
 	} else {
@@ -1067,14 +1067,14 @@ taruib_write_signedfile_if(void * vp, int ofd, char * sigfile,
 		}
 	}
 
-	if (verbose >= 1) {
+	if (verbose >= SWC_VERBOSE_2) {
 		fprintf(stderr, "%s: Archive digest: ", swlib_utilname_get());
 	}
 	calc_sha1digbuf[40] = '\0';
 	sha1digbuf[40] = '\0';
 	if (strlen(sha1digbuf) >= 40 && 
 			strncmp(calc_sha1digbuf, sha1digbuf, 40) == 0) {
-		if (verbose >= 1) {
+		if (verbose >= SWC_VERBOSE_2) {
 			fprintf(stderr, "sha1 OK (Good)\n");
 		}
 	} else {
@@ -1123,15 +1123,15 @@ taruib_write_signedfile_if(void * vp, int ofd, char * sigfile,
 		close(sigfd);
 		uxfio_close(memfd);
 
-		if (verbose > 2) {
-			fprintf(stderr, "swbis: md5: %s from archive.\n",
-								md5digbuf);
-			fprintf(stderr, "swbis: md5: %s calculated.\n",
-							calc_md5digbuf);
-			fprintf(stderr, "swbis: sha1: %s from archive.\n",
-							sha1digbuf);
-			fprintf(stderr, "swbis: sha1: %s calculated.\n", 
-							calc_sha1digbuf);
+		if (verbose >= 4) {
+			fprintf(stderr, "%s: md5: %s from archive.\n",
+						swlib_utilname_get(), md5digbuf);
+			fprintf(stderr, "%s: md5: %s calculated.\n",
+						swlib_utilname_get(), calc_md5digbuf);
+			fprintf(stderr, "%s: sha1: %s from archive.\n",
+						swlib_utilname_get(), sha1digbuf);
+			fprintf(stderr, "%s: sha1: %s calculated.\n", 
+						swlib_utilname_get(), calc_sha1digbuf);
 		}
 	
 		/*
