@@ -1,5 +1,4 @@
-/* $Id: xformat.c,v 1.3 2000/10/14 15:41:14 jhl Exp jhl $
-   xformat.c - read/write archives
+/* xformat.c - read/write archives
  
    Copyright (C) 2000,2004 Jim Lowe
 
@@ -391,7 +390,8 @@ xformat_open(int ifd, int ofd, int format)
 {
 	XFORMAT * xux = (XFORMAT*)malloc(sizeof(XFORMAT));
 	setup_1(xux, format);    
-	xux->ifdM=ifd; xux->ofdM=ofd;
+	xux->ifdM = ifd;
+	xux->ofdM = ofd;
 	return xux;
 }
 	
