@@ -1,5 +1,4 @@
-/* $Id: xformat.h,v 1.3 2000/10/14 15:41:17 jhl Exp jhl $
-   xformat.h - read/write archives
+/* xformat.h - read/write archives
  
    Copyright (C) 2000  Jim Lowe
 
@@ -184,8 +183,6 @@ typedef struct {
 	
 	void xformat_write_archive_stats(XFORMAT * xux, char * name, int fd);
 
-	/* int xformat_u_open_current_file(XFORMAT * xux); */
-
 	int xformat_u_open_file(XFORMAT * xux, char * name);
 
 	int xformat_u_lstat(XFORMAT * xux, char * path, struct stat * st);
