@@ -4,9 +4,12 @@
 #include <sys/stat.h>
 #include "swparser_global.h"
 #include "usgetopt.h"
+#include "swutillib.h"
 #include "swlib.h"
 #include "swi.h"
 #include "xformat.h"
+#include "swevents_array.h"
+#include "swcommon_options.h"
 
 int 
 main (int argc, char ** argv ) {
