@@ -1,6 +1,5 @@
 #ifdef DOTO_ID
-static char testswheader_c[] =
-"$Id: testswheader.c_v 1.1 1999/04/21 02:12:43 jhl Exp jhl $";
+static char testswheader_c[] = "testswheader2.c,v 1.1.1.1";
 #endif
 
 
