@@ -1,6 +1,4 @@
-/* $Id: uinfile.c,v 1.29 2000/01/01 16:31:29 jhl Exp jhl $
- *  uinfile.c: Open a package and fill in a UINFORMAT structure.
- *
+/* uinfile.c: Open a package and fill in a UINFORMAT structure.
  */
 
 /*
@@ -520,7 +518,7 @@ LABEL_REREAD:
 				(*uinformat)->ztypeM = UINFILE_COMPRESSED_RPM;
 			} else if (doieee && dounrpminstall == 0) {
 				fprintf(stderr,
-				"%s: try using --allow-rpm or set swbis_allow_rpm=true in your defaults files\n",
+				"%s: try using the --allow-rpm or --any-format options\n",
 						swlib_utilname_get());
 				return -1;
 			} else {
