@@ -1,7 +1,4 @@
-/* $Id$
- *   testheader4.cxx: An interactive program for testing the swheader
- *			interface.
- *
+/* testheader4.cxx
  */
 
 #include "swuser_config.h"
