@@ -160,7 +160,7 @@ main (int argc, char ** argv)
 	if (!psf) exit(1);
 
 	psf->set_cksum_creation(do_cksum);
-	psf->set_md5_creation(do_md5sum);
+	psf->set_digests1_creation(do_md5sum);
 
 	if (archive_name == NULL && dir_name == NULL) {
 		fprintf(stderr, "invalid usage\n");
