@@ -10,6 +10,7 @@ main(int argc, char ** argv)
 	int i;
 	char ** uargs;
 	char buf[1000];	
+	STROB * tmp = strob_open(10);
 	SWVERID * pattern;
 	SWVERID * candidate_list[20];
 	SWVERID ** p_candidate;
@@ -19,15 +20,15 @@ main(int argc, char ** argv)
 		exit(1);
 	}	
 	pattern = swverid_open(NULL, argv[1]);
-	swverid_print(pattern, buf, sizeof(buf));
-	fprintf(stdout,"pattern_spec: %s\n", buf);
+	swverid_print(pattern, tmp);
+	fprintf(stdout,"pattern_spec: %s\n", strob_str(tmp));
 
 	uargc = 2;
 	i = 0;
 	while (uargc < argc) {
 		candidate_list[i] = swverid_open(NULL, argv[uargc]);
-		swverid_print(candidate_list[i], buf, sizeof(buf));
-		fprintf(stdout,"candidate_spec: %s\n", buf);
+		swverid_print(candidate_list[i], tmp);
+		fprintf(stdout,"candidate_spec: %s\n", strob_str(buf));
 		uargc++; i++;
 	}
 	candidate_list[++i] = NULL;
