@@ -32,7 +32,7 @@ echo
 	export SWPACKAGEPASSFD=3
 	exec 3<$PASSFILE swign  -u "$AUTHOR" -D bin/checksig-nosym.sh -S
 )
-swverify --checksig .
+swverify --scm -d @.
 ret=$?
 rm -fr /var/tmp/swbis-test-user$$
 exit $ret
